{literal}
<script language="javascript">
function displayListings()
{
	document.frm_location.submit();
}
</script>
{/literal}
<div class="top_banner">{$TOP_MAIN_BANNER}<!-- <img src="{$GLOBAL.tpl_url}/images/banner.jpg" alt="" width="943" height="102" /> --></div>
<div id="mid_wrap">
		<!-- START:Left Wrap-->
		<div class="block_wrap" >
			<div class="block_wrap_top" style="padding-bottom:10px;"><!-- --></div>
			<div class="head01 head_bg"> Featured Restaurant</div>
				
				<div class="block_inner text01 " >
					<div style="height:180px;">
					
					<span class="normal_bold"><a  href="{makeLink mod=flyer pg=list}act=flyer_details&flyer_id={$FEATURED_RESTAURANT.flyer_id}{/makeLink}" class="normal_bold">{$FEATURED_RESTAURANT.title|truncate:25}</a></span><br />
					{$FEATURED_RESTAURANT.location_state} &nbsp;{$FEATURED_RESTAURANT.location_city} &nbsp;{if $FEATURED_RESTAURANT.location_zip ne ''}, {$FEATURED_RESTAURANT.location_zip}{/if}
					</span>
					
					
					<p>{$FEATURED_RESTAURANT.description|truncate:320}</p>
					{if $FEATURED_RESTAURANT.title ne ''}
					<table width="265" border="0" cellspacing="0" cellpadding="0">
  
  <tr>
    <td height="19" class="normal_bold1">{$COM_VARIABLES.MOD_LABELS.LBL_HOME_RATING}</td>
    <td class="normal_bold1">{$COM_VARIABLES.MOD_LABELS.LBL_HOME_PRICING}</td>
  </tr>
  <tr>
    <td height="25">{if $FEATURED_RESTAURANT.title ne ''}{if $FEATURED_RESTAURANT.rate ne ''}<img src="{$GLOBAL.tpl_url}/images/rate{$FEATURED_RESTAURANT.rate}.gif"  />{else}<img src="{$GLOBAL.tpl_url}/images/rate0.gif"  /> {/if}{/if}</td>
    <td>{if $FEATURED_RESTAURANT.title ne ''}{if $FEATURED_RESTAURANT.price ne ''}<img src="{$GLOBAL.tpl_url}/images/price{$FEATURED_RESTAURANT.price}.gif"  />{else}<img src="{$GLOBAL.tpl_url}/images/price0.gif"  /> {/if}{/if}</td>
  </tr>
</table>{/if}<div class="clear"></div>
</div>
			<div class="padding02" style="width:280px; height:230px; ">
			
			{if $FEATURED_RESTAURANT.video_code ne ''}
				{$FEATURED_RESTAURANT.video_code} 
			{/if}
			
			</div>
			<div class="link_block_height"><!-- --></div>
			{if $FEATURED_RESTAURANT.title ne ''}
			<div class="link_block">
			
			  <table width="265" border="0" cellspacing="0" cellpadding="2">
                <tr>
                  <td width="20" height="18"><img src="{$GLOBAL.tpl_url}/images/email_icon.jpg" alt="" width="17" height="17" /></td>
                  <td width="93"><a href="{makeLink mod=flyer pg=list}act=flyer_details&flyer_id={$FEATURED_RESTAURANT.flyer_id}{/makeLink}" class="small_text_link">{$COM_VARIABLES.MOD_LABELS.LBL_HOME_EMAIL_FRND}</a></td>
                  <td width="22"><img src="{$GLOBAL.tpl_url}/images/add_wish_list.jpg" width="17" height="17" /></td>
                  <td width="114"><a href="{makeLink mod=flyer pg=list}act=flyer_details&flyer_id={$FEATURED_RESTAURANT.flyer_id}{/makeLink}" class="small_text_link">{$COM_VARIABLES.MOD_LABELS.LBL_HOME_ADD_WISHLIST} </a></td>
                </tr>
                <tr>
                  <td><img src="{$GLOBAL.tpl_url}/images/reviw_icon.jpg" width="17" height="17" /></td>
                  <td><a href="{makeLink mod=flyer pg=list}act=flyer_details&flyer_id={$FEATURED_RESTAURANT.flyer_id}{/makeLink}" class="small_text_link">{$COM_VARIABLES.MOD_LABELS.LBL_HOME_WRITE_REVIEW} </a></td>
                  <td><img src="{$GLOBAL.tpl_url}/images/add_fav.jpg" width="17" height="17" /></td>
                  <td><a href="{makeLink mod=flyer pg=list}act=flyer_details&flyer_id={$FEATURED_RESTAURANT.flyer_id}{/makeLink}" class="small_text_link">{$COM_VARIABLES.MOD_LABELS.LBL_HOME_ADD_FAVORITE}</a></td>
                </tr>
              </table>
			</div>
 {/if}
				</div>
				
				
			<div class="block_wrap_bottom"><!-- --></div>
		</div>
		<!-- END:Left Wrap-->
		
		<!-- START:Right Wrap-->
		<div class="index_right_wrap">
		
			<div class="index_right_wrap_inner">
            <div class="right_top">
              <!-- -->
            </div>
            <div class="right_bg">
              <div class="page_nav"> <a href="#">Home</a> <span class="nav_img"></span> <a href="{makeLink mod=flyer pg=list}act=reservation{/makeLink}">Reservation</a>
                <div class="clear"></div>
              <span class="head_style01">Reservation</span> <span class="head_style04 padding_10" style="text-align:right; float:right;"> 			</span> </div>
			  <br clear="all" />
			   {if $smarty.request.flyer_id eq ''}
			   {if $HIDE_LOCATIONS ne 'Y'}
			  <form name="frm_location" method="post">
			   <table width="100%" border="0" cellspacing="0" cellpadding="0" >
			    
			  <tr>
                  <td width="200" height="30" class="normal_bold1">State:</td>
                  <td><input type="hidden" name="location_country" value="UNITED STATES">
				<span  id="stateblock"  >
				<select name="location_state" id="location_state" class="list_field_form" onChange="changeCounty(this.value,'{$FLYER_VALUE.location_county}')">
				<option>---Select a State---</option>
				</select>
				</span>
				</td>
                </tr>
				<tr>
                  <td width="200" height="30" class="normal_bold1">County:</td>
                  <td><span id="countyblock"  >
				<select name="location_county" class="list_field_form" id="location_county" style="width:135px;" >
				<option>---Select a County---</option>
				{html_options values=$COUNTY_LIST.county_name output=$COUNTY_LIST.county_name selected=$FLYER_VALUE.location_county}
				</select>
				</span></td>
                </tr>
				<tr>
                  <td width="200" height="30" class="normal_bold1">City:</td>
                  <td><span  id="cityblock">
				<select name="location_city" class="list_field_form" id="location_city" style="width:135px;" >
				<option>---Select a City---</option>
				{html_options values=$CITY_LIST.name output=$CITY_LIST.name selected=$smarty.session.city_id}
				{foreach from=$CITY_LIST item=city_val key=fields}		
				<option value="{$city_val.id}" {if $city_val.id eq $smarty.session.city_id}selected{/if}>{$city_val.name}</option>	
				{/foreach}
				</select>
				</span>
				<input type="hidden" name="hid_locations" value="Y">
				</td>
                </tr>
				<tr>
                  <td width="200" height="30" class="normal_bold1">&nbsp;</td>
                  <td align="left">
											<a href="#" class="redButton2"  onClick="javascript:displayListings();"><span>Next</span></a></span>
				<span  id="neighbourhood_block" style="display:none; "></span>
				</td>
                </tr>
			   </table>
			  </form>
			  {/if}
			  {/if}
			  
						<form name="frm_reservation" method="post">
			<div style="padding:15px 10px 0px 10px;  height:550px;">
			  <table width="100%" border="0" cellspacing="0" cellpadding="0" >
				 {if $HIDE_LOCATIONS eq 'Y' || $smarty.request.flyer_id ne ''}
				 {if $AVILABLE_LISTINGS.title ne '' || $FLYER_DATA.ContactInfo.location_street_address ne '' }
                <tr>
                  <td width="200" height="30" class="normal_bold1">Restaurant Name:</td>
                  <td><!-- <span class="normal_bold1">{$FLYER_DATA.title}</span> --> 
				  <select name="restaurnts" style="width:220px;" class="list_field_form" onchange="window.location.href='{makeLink mod=flyer pg=list}act=reservation{/makeLink}&flyer_id='+this.value">
				  <option value="">--- Restaurant ---</option>
   {html_options values=$AVILABLE_LISTINGS.flyer_id output=$AVILABLE_LISTINGS.title selected=$smarty.request.flyer_id}
                  </select></td>
                </tr>
				{else}
				<tr>
                  <td width="200" height="30" class="normal_bold1">&nbsp;</td>
                  <td class="normal_bold1" align="left">No Restaurants Found</td>
                </tr>
				{/if}
				{/if}
				{if $smarty.request.flyer_id ne ''}
                <tr>
                  <td height="30"><span class="normal_bold1"> Address:
</span></td>
                  <td class="normal_bold1">{$FLYER_DATA.ContactInfo.location_street_address},&nbsp; {$FLYER_DATA.ContactInfo.location_city},&nbsp; {$FLYER_DATA.ContactInfo.location_state},&nbsp;  {$FLYER_DATA.ContactInfo.location_zip}</td>
                </tr>

                <tr>
                    <td height="10" colspan="2" align="left" valign="top" class="normal_bold1" ></td>
                </tr>
                <tr>
                  <td height="30" align="left" valign="top"><span class="normal_bold1">Hours:</span></td>
                  <td><table width="239" border="0" cellspacing="0" cellpadding="0">
                   
                    <tr>
                      <td class="td3"> Monday</td>
                      <td height="28" class="td3">{$HOURS_OF_OPERATION.Monday}</td>
                    </tr>
                    <tr>
                      <td class="td4">Tuesday</td>
                      <td height="25" class="td4">{$HOURS_OF_OPERATION.Tuesday}</td>
                    </tr>
                    <tr>
                      <td class="td3"> Wednesday</td>
                      <td height="25" class="td3">{$HOURS_OF_OPERATION.Wednesday}</td>
                    </tr>
                    <tr>
                      <td class="td4">Thursday</td>
                      <td height="25" class="td4">{$HOURS_OF_OPERATION.Thursday}</td>
                    </tr>
                    <tr>
                      <td class="td3"> Friday</td>
                      <td height="25" class="td3">{$HOURS_OF_OPERATION.Friday}</td>
                    </tr>
                    <tr>
                      <td class="td4"> Saturday</td>
                      <td height="25" class="td4">{$HOURS_OF_OPERATION.Saturday} </td>
                    </tr>
                    <tr>
                      <td class="td3"> Sunday</td>
                      <td height="25" class="td3">{$HOURS_OF_OPERATION.Sunday}</td>
                    </tr>
                  </table></td>
                </tr>
                <tr>
                    <td height="10" colspan="2" align="left" valign="top" class="normal_bold1" ></td>
                </tr>
                <tr>
                  <td height="30" class="normal_bold1" >Date:</td>
                  <td><table width="330" border="0" cellspacing="0" cellpadding="0">
                    <tr>
                      <td >
					    {html_select_date prefix="date_" time=$time start_year=$smarty.request.Expiry_Year|default:"+0" end_year="+10" display_days=true }
					 </td>
                    </tr>
                  </table></td>
                </tr>
                <tr>
                  <td height="30" class="normal_bold1" >Time:</td>
                  <td>{html_select_time use_24_hours=false display_minutes=true display_seconds=false prefix=time_}</td>
                </tr>
               
                <tr>
                  <td height="30" class="normal_bold1" >Party Size:</td>
                  <td><input type="text" name="party_size" style="width:100px;" class="list_field_form">
                   </td>
                </tr>
              <!--   <tr>
                  <td height="30" class="normal_bold1" > Preferred Section:</td>
                  <td><select name="select2" style="width:100px;" class="list_field_form">
                    </select></td>
                </tr> -->

                <tr>
                  <td height="10" colspan="2" align="left" valign="top" class="normal_bold1" ></td>
                </tr>
                <tr>
                  <td height="30" align="left" valign="top" class="normal_bold1" >Special Request / Occasion:</td>
                  <td><textarea name="special_request" class="text_area" style="width:200px;height:100px;"></textarea></td>
                </tr>
                <tr>
                  <td height="10" colspan="2" align="left" valign="top" class="normal_bold1" ></td>
                </tr>
                <!-- <tr>
                  <td height="20" align="left" valign="top" class="normal_bold1" >&nbsp;</td>
                  <td height="20" align="left" valign="top" ><input type="checkbox" name="gift_cirtificate" value="Yes" />
                    <label for="xHaveGC">I Have a Gift Certificate issued by localrestaurant.com</label> 
					<input type="hidden" name="to_email_address" value="{$FLYER_DATA.ContactInfo.contact_email}"> </td>
                </tr> -->
                <tr>
                  <td height="20" colspan="2" align="left" valign="top" class="normal_bold1" >&nbsp;</td>
                </tr>
                <tr>
                  <td height="30" align="left" valign="top" class="normal_bold1" >&nbsp;</td>
                  <td><table width="230" border="0" align="left" cellpadding="0" cellspacing="0">
                      <tr>
                        <td><a class="top_btn" href="#" onClick="document.frm_reservation.submit();" ><span>Submit Reservation </span></a></td>
                      </tr>
					 {/if}
                  </table></td>
                </tr>
              </table></form>
			  <p>&nbsp;</p>
			  <br clear="all" />
			</div>
            </div>
            <div class="right_bottom">
              <!-- -->
            </div>
			
          </div>
			<div class="clear"></div>
			
			<!--Banner bottom BOX -->
			<!--Banner bottom BOX -->
        </div>
		<!-- END:Right Wrap-->
		<div class="clear"></div>
	</div>