<div style="width:740px;">
	<div style="border-bottom:1px solid #f1f1f1; padding-bottom:3px;">
		<table width="100%" cellpadding="0" cellspacing="0">
			<tr>
				<td width="50%"><span style="font-size:20px; font-weight:bold; color:#000000; font-family:tahoma;">localrestaurant.com</span><span style="font-size:20px; font-weight:normal; color:#1b4e2d; font-family:tahoma;"> | Forwarded Listings </span> </td>
				<td align="right">&nbsp;</td>
			</tr>
		</table>
	</div>
	<div style="height:5px;"></div>

<!--	<div style="border:1px solid #f1f1f1; background-color: #E4E4C9; padding:3px; margin-top:3px; margin-bottom:3px; font-family:verdana; font-size:11px; line-height:18px;"><span style="font-weight:bold">$sender</span> has forwarded this listing which may be of interest to you<br/>
	  If you cannot see this listing, please click on the following URL: <a style="color:#1b4e2d;" href="http://vimson.vflyer.com/4/index.html">http://vimson.vflyer.com/4/index.html</a></div> 
-->

<div style="padding:3px 0px 3px 0px; margin:3px 0px 3px 0px; border-bottom:1px solid #f1f1f1; font-family:verdana; font-size:11px; line-height:18px;"><span style="font-weight:bold;">{$SENDER}'s message: </span><span>{$MESSAGE}</span></div>

<!--
<div style="padding:3px; font-family:verdana; font-size:11px; line-height:18px;"><span>If you don't see the link, or if you click on the link and it appears broken, </span><span>please copy and paste the URL into a new browser window.</span></div>

-->

	
	
	
</div>
{$FLYER_CONTENT}