{literal}
<script language="javascript">
function AddtoFilter(item_id,item_name,div_name)
{
	var selectedFilter	=	'div_seleted_filter_' + item_id;
	var	CurrentFilter	=	document.getElementById('div_selected_filters').innerHTML;
	var newFilter		=	'<div class="filter_link" id="div_seleted_filter_'+item_id+'"><a href="javascript:void(0);" onClick="javascript:RemovefromFilter(\'div_filter_cuisine_'+item_id+'\',\''+selectedFilter+'\');"><img src="{/literal}{$GLOBAL.tpl_url}{literal}/images/minus_icon.jpg" width="11" height="13" align="top" />&nbsp;'+item_name+' </a><input type="hidden" name="'+item_id+'" value="'+item_id+'"></div>';
	CurrentFilter		=	CurrentFilter+newFilter;
	document.getElementById('div_selected_filters').innerHTML	=	CurrentFilter;
	
	document.getElementById(div_name).style.display	=	'none';
}
function RemovefromFilter(div_name,filter_div)
{ 
	document.getElementById(div_name).style.display	=	'block';
	document.getElementById(filter_div).style.display	=	'none';
}

function showCuisineList()
{ 
	if(document.getElementById('div_cuisine_list').style.display == 'none')
	{
		document.getElementById('div_cuisine_list').style.display =	'block';
		document.getElementById('div_nhood_list').style.display   =	'none';
		document.getElementById('div_feature_list').style.display =	'none';
	}
	else
	{
			document.getElementById('div_cuisine_list').style.display =	'none';
	}

}

function showNhoodList()
{ 
	if(document.getElementById('div_nhood_list').style.display == 'none')
	{
		document.getElementById('div_nhood_list').style.display   =	'block';
		document.getElementById('div_feature_list').style.display =	'none';
		document.getElementById('div_cuisine_list').style.display =	'none';
	}
	else
	{
			document.getElementById('div_nhood_list').style.display =	'none';
	}

}

function showFeaturesList()
{ 
	if(document.getElementById('div_feature_list').style.display == 'none')
	{
		document.getElementById('div_feature_list').style.display =	'block';
		document.getElementById('div_nhood_list').style.display   =	'none';
		document.getElementById('div_cuisine_list').style.display =	'none';
	}
	else
	{
			document.getElementById('div_feature_list').style.display =	'none';
	}

}
function submitFilters()
{
	document.frm_filters.hid_search_fiters.value	=	"Y";	
	document.frm_filters.method	=	"post";
	document.frm_filters.submit();
}
</script>

{/literal}
<div id="inner_mid" style="padding-bottom:0px;">
		<!-- START:Left Wrap-->
		<div id="left_wrap">
		
		
		
			<!-- START:Profile Wrap-->
			 <form  name="frm_filters" method="post" action="">
			<div class="box_wrap">
				<div class="box_wrap_top"><!-- --></div>
				<div class="box_wrap_inner" style="padding:0px 10px 0px 10px;">
				
					<div>
					  <span class="head_style01" style="float:inherit; padding-bottom:15px; display:block;">Filter</span>
						<table width="164" border="0" cellspacing="0" cellpadding="0">
						<tr>
						<td align="left" valign="top"><img src="{$GLOBAL.tpl_url}/images/boxtop_bg.jpg" width="160" height="6" /></td>
						</tr>
						<tr>
						<td align="left" valign="top">
						<div class="filter_top" id="div_selected_filters"> 	</div>	
						</td>
						</tr>
						<tr>
						<td align="left" valign="top"><img src="{$GLOBAL.tpl_url}/images/boxbtm_bg.jpg" width="160" height="6" /></td>
						</tr>
						<tr>
						<td align="left" valign="top">&nbsp;</td>
						</tr>
						</table>
					 <div class="filterMenu_holder" >
					  <div class="filterMenu" onClick="javascript:showCuisineList();"><a href="javascript:void(0);"  >Cusine</a></div>
					  <div  id="div_cuisine_list" style="display:none; position:absolute; ">
							  <table width="164" border="0" cellspacing="0" cellpadding="0">
								<tr>
								<td align="left" valign="top"><img src="{$GLOBAL.tpl_url}/images/boxtop_bg.jpg" width="160" height="6" /></td>
								</tr>
								<tr>
								<td align="left" valign="top">
								<div class="filter_top">
								{foreach from=$CUISINES.items item=cuisines}
								<div class="filter_link" id="div_filter_cuisine_{$cuisines.item_id}"><a  href="javascript:void(0);" class="normal_blicklink" onClick="javascript:AddtoFilter('{$cuisines.item_id}','{$cuisines.item_name}','div_filter_cuisine_{$cuisines.item_id}');"><img src="{$GLOBAL.tpl_url}/images/plus_icon.jpg" width="11" height="13" align="top" />&nbsp;{$cuisines.item_name}</a></div>
								{/foreach}						
								</div>	
								<div class="clear"><!-- --></div></td>
								</tr>
								<tr>
								<td align="left" valign="top"><img src="{$GLOBAL.tpl_url}/images/boxbtm_bg.jpg" width="160" height="6" /></td>
								</tr>
								<tr>
								<td align="left" valign="top">&nbsp;</td>
								</tr>
								</table>
						</div>
					  
					   <div class="filterMenu" onClick="javascript:showFeaturesList();"><a href="javascript:void(0);" >Features</a></div>
					     <div  id="div_feature_list" style="display:none; position:absolute; ">
							  <table width="164" border="0" cellspacing="0" cellpadding="0">
								<tr>
								<td align="left" valign="top"><img src="{$GLOBAL.tpl_url}/images/boxtop_bg.jpg" width="160" height="6" /></td>
								</tr>
								<tr>
								<td align="left" valign="top">
								<div class="filter_top">
								{foreach from=$SEARCH_FEATURES.items item=feature}
								<div class="filter_link" id="div_filter_cuisine_{$feature.item_id}"><a  href="javascript:void(0);" class="normal_blicklink" onClick="javascript:AddtoFilter('{$feature.item_id}','{$feature.item_name}','div_filter_cuisine_{$feature.item_id}');"><img src="{$GLOBAL.tpl_url}/images/plus_icon.jpg" width="11" height="13" align="top" />&nbsp;{$feature.item_name}</a></div>
								{/foreach}						
								</div>	
								<div class="clear"><!-- --></div></td>
								</tr>
								<tr>
								<td align="left" valign="top"><img src="{$GLOBAL.tpl_url}/images/boxbtm_bg.jpg" width="160" height="6" /></td>
								</tr>
								<tr>
								<td align="left" valign="top">&nbsp;</td>
								</tr>
								</table>
						</div>
						
					    <div class="filterMenu" onClick="javascript:showNhoodList();"><a href="javascript:void(0);" > Neighborhood </a></div>
						<div  id="div_nhood_list" style="display:none; position:absolute; ">
							  <table width="164" border="0" cellspacing="0" cellpadding="0">
								<tr>
								<td align="left" valign="top"><img src="{$GLOBAL.tpl_url}/images/boxtop_bg.jpg" width="160" height="6" /></td>
								</tr>
								<tr>
								<td align="left" valign="top">
								<div class="filter_top">
								{foreach from=$NEIGHBORHOOD.items item=nhood}
								<div class="filter_link" id="div_filter_cuisine_{$nhood.item_id}"><a  href="javascript:void(0);" class="normal_blicklink" onClick="javascript:AddtoFilter('{$nhood.item_id}','{$nhood.item_name}','div_filter_cuisine_{$nhood.item_id}');"><img src="{$GLOBAL.tpl_url}/images/plus_icon.jpg" width="11" height="13" align="top" />&nbsp;{$nhood.item_name}</a></div>
								{/foreach}						
								</div>	
								<div class="clear"><!-- --></div></td>
								</tr>
								<tr>
								<td align="left" valign="top"><img src="{$GLOBAL.tpl_url}/images/boxbtm_bg.jpg" width="160" height="6" /></td>
								</tr>
								<tr>
								<td align="left" valign="top">&nbsp;</td>
								</tr>
								</table>
						</div>
						
					</div> 
					<div class="filterHead">Pricing</div>
					<div class="filterMenu_holder" style="padding:5px 0px;">
					  <table width="164" border="0" cellspacing="0" cellpadding="0">
                        <tr>
                          <td width="22"><input type="checkbox" name="chk_pricing_1" value="1" />
                          </td>
                          <td width="54"><img src="{$GLOBAL.tpl_url}/images/dolor.jpg" alt="" width="7" height="11" /></td>
                          <td width="22"><input type="checkbox" name="chk_pricing_4" value="4" /></td>
                          <td width="66"><img src="{$GLOBAL.tpl_url}/images/dolor.jpg" alt="" width="7" height="11" /><img src="{$GLOBAL.tpl_url}/images/dolor.jpg" alt="" width="7" height="11" /><img src="{$GLOBAL.tpl_url}/images/dolor.jpg" alt="" width="7" height="11" /><img src="{$GLOBAL.tpl_url}/images/dolor.jpg" alt="" width="7" height="11" /></td>
                        </tr>
                        <tr>
                          <td><input type="checkbox" name="chk_pricing_2" value="2" /></td>
                          <td><img src="{$GLOBAL.tpl_url}/images/dolor.jpg" alt="" width="7" height="11" /><img src="{$GLOBAL.tpl_url}/images/dolor.jpg" alt="" width="7" height="11" /></td>
                          <td><input type="checkbox" name="chk_pricing_5" value="5" /></td>
                          <td><img src="{$GLOBAL.tpl_url}/images/dolor.jpg" alt="" width="7" height="11" /><img src="{$GLOBAL.tpl_url}/images/dolor.jpg" alt="" width="7" height="11" /><img src="{$GLOBAL.tpl_url}/images/dolor.jpg" alt="" width="7" height="11" /><img src="{$GLOBAL.tpl_url}/images/dolor.jpg" alt="" width="7" height="11" /><img src="{$GLOBAL.tpl_url}/images/dolor.jpg" alt="" width="7" height="11" /></td>
                        </tr>
                        <tr>
                          <td><input type="checkbox" name="chk_pricing_3" value="3" /></td>
                          <td><img src="{$GLOBAL.tpl_url}/images/dolor.jpg" alt="" width="7" height="11" /><img src="{$GLOBAL.tpl_url}/images/dolor.jpg" alt="" width="7" height="11" /><img src="{$GLOBAL.tpl_url}/images/dolor.jpg" alt="" width="7" height="11" /></td>
                          <td>&nbsp;</td>
                          <td>&nbsp;</td>
                        </tr>
                      </table>
					</div>
					<div class="filterHead">Rating</div>
					<div class="filterMenu_holder" style="padding:5px 0px;">
					  <table width="164" border="0" cellspacing="0" cellpadding="0">
                        <tr>
                          <td width="22"><input type="checkbox" name="chk_rating_1" value="1" />
                          </td>
                          <td width="54"><img src="{$GLOBAL.tpl_url}/images/bowl.jpg" alt="" width="11" height="16" /></td>
                          <td width="22"><input type="checkbox" name="chk_rating_4" value="4" /></td>
                          <td width="66"><img src="{$GLOBAL.tpl_url}/images/bowl.jpg" alt="" width="11" height="16" /><img src="{$GLOBAL.tpl_url}/images/bowl.jpg" alt="" width="11" height="16" /><img src="{$GLOBAL.tpl_url}/images/bowl.jpg" alt="" width="11" height="16" /><img src="{$GLOBAL.tpl_url}/images/bowl.jpg" alt="" width="11" height="16" /></td>
                        </tr>
                        <tr>
                          <td><input type="checkbox" name="chk_rating_2" value="2" /></td>
                          <td><img src="{$GLOBAL.tpl_url}/images/bowl.jpg" alt="" width="11" height="16" /><img src="{$GLOBAL.tpl_url}/images/bowl.jpg" alt="" width="11" height="16" /></td>
                          <td><input type="checkbox" name="chk_rating_5" value="5" /></td>
                          <td><img src="{$GLOBAL.tpl_url}/images/bowl.jpg" alt="" width="11" height="16" /><img src="{$GLOBAL.tpl_url}/images/bowl.jpg" alt="" width="11" height="16" /><img src="{$GLOBAL.tpl_url}/images/bowl.jpg" alt="" width="11" height="16" /><img src="{$GLOBAL.tpl_url}/images/bowl.jpg" alt="" width="11" height="16" /><img src="{$GLOBAL.tpl_url}/images/bowl.jpg" alt="" width="11" height="16" /></td>
                        </tr>
                        <tr>
                          <td><input type="checkbox" name="chk_rating_3" value="3" /></td>
                          <td><img src="{$GLOBAL.tpl_url}/images/bowl.jpg" alt="" width="11" height="16" /><img src="{$GLOBAL.tpl_url}/images/bowl.jpg" alt="" width="11" height="16" /><img src="{$GLOBAL.tpl_url}/images/bowl.jpg" alt="" width="11" height="16" /></td>
                          <td>&nbsp;</td>
                          <td>&nbsp;</td>
                        </tr>
                      </table>
					</div>
					<div class="filterMenu_holder" style="padding:5px 0px;"><input type="hidden" name="hid_search_fiters" value="N">
					<input type="hidden" name="txt_city" value="{$smarty.request.txt_city}">
					<input type="hidden" name="txt_restaurant" value="{$smarty.request.txt_restaurant}">
					<a href="#" onClick="javascript:submitFilters();"><img src="{$GLOBAL.tpl_url}/images/btn_search.jpg" alt="" width="91" height="29" border="0" /></a></div>
			 		</div>
				
				
					
				</div>
				<div class="box_wrap_btm"><!-- --></div>
		  </div>
		 </form>
		  <div class="padding08"><!-- --></div>
			<!-- END:Profile Wrap-->
		
			<!-- START:Profile Wrap-->
			<div class="box_wrap">
			
				<div class="box_wrap_top"><!-- --></div>				
			  <div class="box_wrap_inner" style="padding:0px 0px 0px 10px;">
					
					<div class="">
							
					  <span class="head_style01 headstyle_padding">{$COM_VARIABLES.MOD_LABELS.LBL_HOME_RECENT}</span>
					  
					   <span class="padding02"><!-- --></span>
					   
					    {foreach from=$RECENT_RESTAURANTS item=recent}
					  <div class="raw01" style="width:170px;"><span class="raw01"><a  href="{makeLink mod=flyer pg=list}act=flyer_details&flyer_id={$recent.flyer_id}{/makeLink}" border="0">
						{if $recent.image ne ''} 
              	 <img src="{$GLOBAL.modbase_url}/flyer/images/widget/thumb/{$recent.image}" alt="{$recent.title}"  class="img_style"/>
				{else}
				 <img src="{$GLOBAL.modbase_url}/flyer/images/widget/thumb/default.jpg" alt="{$recent.title}"  class="img_style"/>
				{/if}</a></span>
					  <div class="raw01_content" style="width:110px;">
					    <table width="110" border="0" cellspacing="0" cellpadding="0">
					      <tr>
					        <td align="left" valign="top"><span class="normal_bold"><a  href="{makeLink mod=flyer pg=list}act=flyer_details&flyer_id={$recent.flyer_id}{/makeLink}" class="normal_bold">{$recent.title|truncate:25}</a></span><br />
				            {$recent.location_city}&nbsp; {$recent.location_zip} </td>
                          </tr>
					      
				        </table>
					  </div>
						      <div class="clear"></div>
						  
				  </div>
				   <span class="line_bg" style="padding-top:0px;"><!-- --></span>
				   {/foreach}
				   
								  
			  </div>
				
					
			  </div>
				<div class="box_wrap_btm"><!-- --></div>
			</div>
			<!-- END:Profile Wrap-->
			<div class="padding08"><!-- --></div>
			<!-- START:Profile Wrap-->
			<div class="box_wrap">
				<div class="box_wrap_top"><!-- --></div>
				<div class="box_wrap_inner" style="padding:0px 0px 0px 10px;">
					
					<div class="">
							
					  <span class="head_style01 headstyle_padding">Special Offers &amp; Coupons</span>
					  
					   <span class="padding02"><!-- --></span>
					   {foreach from=$HOME_COUPONS item=latest_coupons}
					   <div class="raw01" style="width:170px;"><span class="raw01">
					   <a  href="{makeLink mod=flyer pg=list}act=coupons&flyer_id={$latest_coupons.flyer_id}{/makeLink}" border="0">
						{if $latest_coupons.image ne ''} 
						 <img src="{$GLOBAL.modbase_url}/flyer/images/widget/thumb/{$latest_coupons.image}" alt="{$latest_coupons.title}"  class="img_style"/>
						{else}
						 <img src="{$GLOBAL.modbase_url}/flyer/images/widget/thumb/default.jpg" alt="{$latest_coupons.title}"  class="img_style"/>
						{/if}</a>
					   </span>
					  <div class="raw01_content" style="width:110px;">
					    <table width="110" border="0" cellspacing="0" cellpadding="0">
					      <tr>
					        <td align="left" valign="top"><span class="normal_bold"><a  href="{makeLink mod=flyer pg=list}act=coupons&flyer_id={$latest_coupons.flyer_id}{/makeLink}" border="0" class="normal_bold">{$latest_coupons.title|truncate:20}</a></span><br />
				           {$latest_coupons.description|truncate:50}</td>
                          </tr>
					      
				        </table>
					  </div>
						      <div class="clear"></div>
						  
				  </div>
				   <span class="line_bg" style="padding-top:0px;"><!-- --></span>
				   {/foreach}
				   
				  <div class="padding02" style="text-align:left" ><a href="#" class="normal_redlink_bold1">More Details</a></div>
				  
			  </div>
				
					
			  </div>
				<div class="box_wrap_btm"><!-- --></div>
			</div>
			<!-- END:Profile Wrap-->
			<div class="padding08"><!-- --></div>
			<!-- START:Profile Wrap-->
			<div class="box_wrap">
				<div class="box_wrap_top"><!-- --></div>
				<div class="box_wrap_inner" style="padding:0px;">
					
					
					
					<div style="text-align:center;"> {$GADD3}</div>
					
				
					
				</div>
				<div class="box_wrap_btm"><!-- --></div>
			</div>
			<!-- END:Profile Wrap-->
			<div class="padding08"><!-- --></div>
			
			
		</div>
		<!-- END:Left Wrap-->
		
		<!-- START:Right Wrap-->
		<div id="right_wrap">
			<div class="ad_wrap01">{$GADD}</div>
			
			<div class="padding08">
				<div style="width:520px; float:left; ">
				<div class="profile_wrap">
					<div class="profile_wrap_top"><!-- --></div>
				  <div class="profile_wrap_inner">
				  
				  <!--Coupon1 -->
				  
				  
				  {foreach from=$COUPON_DETAILS item=coupon}
				  <div class="coupon">
					<table width="100%" border="0" cellspacing="0" cellpadding="5">
							  <tr>
								<td height="35" class="coupon_head">{$coupon.name}</td>
							  </tr>
							  <tr>
								<td height="180" align="left" valign="top"><table width="100%" border="0" cellspacing="0" cellpadding="0">
								  <tr>
									<td width="33%" height="30" align="left" valign="middle">Valid</td>
									<td width="67%">{$coupon.valid_from|date_format:"%B %e %Y"} &nbsp;-&nbsp; {$coupon.valid_to|date_format:"%B %e %Y"} </td>
								  </tr>
								 <!--  <tr>
									<td height="30">Days Available </td>
									<td align="left" valign="middle">Any day of the week </td>
								  </tr> -->
								  <tr>
									<td height="30">Time Available </td>
									<td align="left" valign="middle">{$coupon->time_avilable_from|date_format:"%r "}&nbsp;- &nbsp;{$coupon->time_avilable_to|date_format:"%r"} </td>
								  </tr>
								   <tr>
									<td height="30">Offer </td>
									<td align="left" valign="middle">{if $coupon->price ne ''}{$coupons->price} {if $coupon->discount eq Price}${else}%{/if}{/if}</td>
								  </tr>
								   <tr>
									
									<td align="left" valign="middle" colspan="2"  height="20">{$coupon->offer_description}</td>
								  </tr>
								
								   <tr>
								    <td height="10" colspan="2" class="red_bold">{$coupon->title},
                                      <span>{$coupon->location_city|lower|capitalize},{$coupon->location_zip}</span></td>
							      </tr>
								   <tr>
								    <td height="10" colspan="2" class="red_bold">{$coupon->contact_phone}</td>
							      </tr>
								</table></td>
							  </tr>
							  <tr>
								<td height="55" align="left" valign="top" class="coupon_rule"><span>Rules: </span>{$coupon.rules}</td>
							  </tr>  
					</table>
			  			</div>
					 <!--Coupon1 -->
					  <div class="padding03"><table width="279" border="0" align="right" cellpadding="0" cellspacing="0">
						  <tr>
							<td width="114" class="print"><a href="{makeLink mod=flyer pg=list}act=coupon_details&coupon_id={$coupon.id}{/makeLink}">Print this page</a></td>
							<td width="165" class="reservation"><a href="#">Make a reservation</a></td>
						  </tr>
						</table>
						</div>
						<div class="clear"></div>
						<!--Coupon2 -->
						<div class="padding02">	</div>
						{/foreach}
						
						<!--Coupon 5 -->
		  		  </div>
					<div class="profile_wrap_bottom"><!-- --></div>
					
				</div>	
				<div class="clear"></div>
				<div class="padding08"><!-- --></div>			
				</div>
				<div class="profile_right_wrap">
				
					<div class="profile_right_wrap_content">
						<div class="profile_right_wrap_top"><!-- --></div>
							<div class="profile_right_wrap_inner" style="height:315px;">
							
								<span class="head03">Local Restaurants You Might Like</span>
								 <span class="line_bg"><!-- --></span>
						
						<div class="raw01" style="width:190px;">
						<img src="{$GLOBAL.tpl_url}/images/food_img.jpg" alt="" width="50" height="50"  class="img_style"/>
							<div class="raw01_content" style="width:130px;">
							  <table width="130" border="0" cellspacing="0" cellpadding="0">
                                <tr>
                                  <td align="left" valign="top"><span class="normal_bold">bhuvananereree</span><br />
                                  New York City, NY 10029 </td>
                                </tr>
                                <tr>
                                  <td align="left" valign="top">Cuiseine offers high-end private dining with...</td>
                                </tr>
                              </table>
							</div>
						    <div class="clear"></div>
						<div class="line_bg"><!-- --></div>
					</div>
							
				  <div class="raw01" style="width:190px;"><span class="raw01 "><img src="{$GLOBAL.tpl_url}/images/img_01.jpg" alt=""  class="img_style"/></span>
				    <div class="raw01_content" style="width:130px;">
			  <table width="130" border="0" cellspacing="0" cellpadding="0">
                                <tr>
                                  <td align="left" valign="top"><span class="normal_bold">bhuvananereree</span><br />
                                  New York City, NY 10029 </td>
                                </tr>
                                <tr>
                                  <td align="left" valign="top">Cuiseine offers high-end private dining with...</td>
                                </tr>
                      </table>
							</div>
						    <div class="clear"></div>
						<div class="line_bg"><!-- --></div>
					</div>	
					
					<div class="raw01" style="width:190px;"><span class="raw01 "><img src="{$GLOBAL.tpl_url}/images/img_01.jpg" alt=""  class="img_style"/></span>
					  <div class="raw01_content" style="width:130px;">
					    <table width="130" border="0" cellspacing="0" cellpadding="0">
					      <tr>
					        <td align="left" valign="top"><span class="normal_bold">bhuvananereree</span><br />
					          New York City, NY 10029 </td>
                          </tr>
					      <tr>
					        <td align="left" valign="top">Cuiseine offers high-end private dining with...</td>
                          </tr>
				        </table>
					  </div>
						      <div class="clear"></div>
						  <div class="padding02" style="text-align:right" ><a href="#" class="normal_redlink_bold1">View More</a></div>
					  </div></div>
						<div class="profile_right_wrap_bottom"><!-- --></div>
					</div>
					<div class="clear"></div>
					<div class="padding08"><!-- --></div>
					
					<div class="profile_right_wrap_content">
						<div class="profile_right_wrap_top"><!-- --></div>
							<div class="profile_right_wrap_inner" style="height:283px;">
							
								<span class="head03">Local Restaurants You Might Like</span>
								 <span class="line_bg" style="padding-top:0px;"><!-- --></span>
						
						<div class="raw01" style="width:190px;">
						<img src="{$GLOBAL.tpl_url}/images/food_img.jpg" alt="" width="50" height="50"  class="img_style"/>
							<div class="raw01_content" style="width:130px;">
							  <table width="130" border="0" cellspacing="0" cellpadding="0">
                                <tr>
                                  <td align="left" valign="top"><span class="normal_bold">bhuvananereree</span><br />
                                  New York City, NY 10029 </td>
                                </tr>
                                <tr>
                                  <td align="left" valign="top">Cuiseine offers high-end private dining with...</td>
                                </tr>
                              </table>
							</div>
						    <div class="clear"></div>
						<div class="line_bg" style="padding-top:0px;"><!-- --></div>
					</div>
							
				  <div class="raw01" style="width:190px;"><span class="raw01 "><img src="{$GLOBAL.tpl_url}/images/img_01.jpg" alt=""  class="img_style"/></span>
				    <div class="raw01_content" style="width:130px;">
			  <table width="130" border="0" cellspacing="0" cellpadding="0">
                                <tr>
                                  <td align="left" valign="top"><span class="normal_bold">bhuvananereree</span><br />
                                  New York City, NY 10029 </td>
                                </tr>
                                <tr>
                                  <td align="left" valign="top">Cuiseine offers high-end private dining with...</td>
                                </tr>
                      </table>
							</div>
						    <div class="clear"></div>
						<div class="line_bg" style="padding-top:0px;"><!-- --></div>
					</div>	
					
					<div class="raw01" style="width:190px;"><span class="raw01 "><img src="{$GLOBAL.tpl_url}/images/img_01.jpg" alt=""  class="img_style"/></span>
					  <div class="raw01_content" style="width:130px;">
					    <table width="130" border="0" cellspacing="0" cellpadding="0">
					      <tr>
					        <td align="left" valign="top"><span class="normal_bold">bhuvananereree</span><br />
					          New York City, NY 10029 </td>
                          </tr>
					      <tr>
					        <td align="left" valign="top">Cuiseine offers high-end private dining with...</td>
                          </tr>
				        </table>
					  </div>
						      <div class="clear"></div>
						  <div class="padding02" style="text-align:right" ><a href="#" class="normal_redlink_bold1">More Offers </a></div>
					  </div></div>
						<div class="profile_right_wrap_bottom"><!-- --></div>
					</div>
					
				</div>
				
				<div class="clear"></div>
			</div>
			
		
		</div>
		<!-- END:Right Wrap-->
		
		
		<br clear="all" />
	</div>