{literal}
<script language="javascript">
function searchCuisine(cuisine_id)
{
	document.frm_cuisine.cuisine_id.value	=	cuisine_id;
	document.frm_cuisine.method		=	"post";
	document.frm_cuisine.submit();
	
}
</script>
{/literal}
<div class="top_banner">{$TOP_MAIN_BANNER}</div>
<div id="mid_wrap">
		<!-- START:Left Wrap-->
		<div class="block_wrap" >
			<div class="block_wrap_top" style="padding-bottom:10px;"><!-- --></div>
			<div class="head01 head_bg"> Featured Restaurant</div>
				
				<div class="block_inner text01 " >
					<div style="height:180px;">
					
					<span class="normal_bold"><a  href="{makeLink mod=flyer pg=list}act=flyer_details&flyer_id={$FEATURED_RESTAURANT.flyer_id}{/makeLink}" class="normal_bold">{$FEATURED_RESTAURANT.title|truncate:25}</a></span><br />
					{$FEATURED_RESTAURANT.location_state} &nbsp;{$FEATURED_RESTAURANT.location_city} &nbsp;{if $FEATURED_RESTAURANT.location_zip ne ''}, {$FEATURED_RESTAURANT.location_zip}{/if}
					</span>
					
					
					<p>{$FEATURED_RESTAURANT.description|truncate:320}</p>
					{if $FEATURED_RESTAURANT.title ne ''}
					<table width="265" border="0" cellspacing="0" cellpadding="0">
  
  <tr>
    <td height="19" class="normal_bold1">{$COM_VARIABLES.MOD_LABELS.LBL_HOME_RATING}</td>
    <td class="normal_bold1">{$COM_VARIABLES.MOD_LABELS.LBL_HOME_PRICING}</td>
  </tr>
  <tr>
    <td height="25">{if $FEATURED_RESTAURANT.title ne ''}{if $FEATURED_RESTAURANT.rate ne ''}<img src="{$GLOBAL.tpl_url}/images/rate{$FEATURED_RESTAURANT.rate}.gif"  />{else}<img src="{$GLOBAL.tpl_url}/images/rate0.gif"  /> {/if}{/if}</td>
    <td>{if $FEATURED_RESTAURANT.title ne ''}{if $FEATURED_RESTAURANT.price ne ''}<img src="{$GLOBAL.tpl_url}/images/price{$FEATURED_RESTAURANT.price}.gif"  />{else}<img src="{$GLOBAL.tpl_url}/images/price0.gif"  /> {/if}{/if}</td>
  </tr>
</table>{/if}<div class="clear"></div>
</div>
			<div class="padding02" style="width:280px; height:230px; ">
			
			{if $FEATURED_RESTAURANT.video_code ne ''}
				{$FEATURED_RESTAURANT.video_code} 
			{/if}
			
			</div>
			<div class="link_block_height"><!-- --></div>
			{if $FEATURED_RESTAURANT.title ne ''}
			<div class="link_block">
			
			  <table width="265" border="0" cellspacing="0" cellpadding="2">
                <tr>
                  <td width="20" height="18"><img src="{$GLOBAL.tpl_url}/images/email_icon.jpg" alt="" width="17" height="17" /></td>
                  <td width="93"><a href="{makeLink mod=flyer pg=list}act=flyer_details&flyer_id={$FEATURED_RESTAURANT.flyer_id}{/makeLink}" class="small_text_link">{$COM_VARIABLES.MOD_LABELS.LBL_HOME_EMAIL_FRND}</a></td>
                  <td width="22"><img src="{$GLOBAL.tpl_url}/images/add_wish_list.jpg" width="17" height="17" /></td>
                  <td width="114"><a href="{makeLink mod=flyer pg=list}act=flyer_details&flyer_id={$FEATURED_RESTAURANT.flyer_id}{/makeLink}" class="small_text_link">{$COM_VARIABLES.MOD_LABELS.LBL_HOME_ADD_WISHLIST} </a></td>
                </tr>
                <tr>
                  <td><img src="{$GLOBAL.tpl_url}/images/reviw_icon.jpg" width="17" height="17" /></td>
                  <td><a href="{makeLink mod=flyer pg=list}act=flyer_details&flyer_id={$FEATURED_RESTAURANT.flyer_id}{/makeLink}" class="small_text_link">{$COM_VARIABLES.MOD_LABELS.LBL_HOME_WRITE_REVIEW} </a></td>
                  <td><img src="{$GLOBAL.tpl_url}/images/add_fav.jpg" width="17" height="17" /></td>
                  <td><a href="{makeLink mod=flyer pg=list}act=flyer_details&flyer_id={$FEATURED_RESTAURANT.flyer_id}{/makeLink}" class="small_text_link">{$COM_VARIABLES.MOD_LABELS.LBL_HOME_ADD_FAVORITE}</a></td>
                </tr>
              </table>
			</div>
 {/if}
				</div>
				
				
			<div class="block_wrap_bottom"><!-- --></div>
		</div>
		<!-- END:Left Wrap-->
		
		<!-- START:Right Wrap-->
		<div class="index_right_wrap">
		
			<div class="cuisine_wrap">
				<div class="cuisine_wrap_top"><!-- --></div>
					<div class="cusine_bg">
						<div class="page_nav" style="height:34px;">
						<a href="{$GLOBAL.site_url}">Home</a> <span class="page_nav_img"></span> <a href="{makeLink mod=flyer pg=list}act=allcity{/makeLink}">Restaurants</a><!-- <span class="page_nav_img"></span> <a href="#">Georgia</a> <span class="page_nav_img"></span> <a href="#">Atlanta</a> -->
						<div class="clear"></div>
						</div>
					
						<div >
						<div class="head02">Cuisines</div>
						<table width="586" border="0" cellspacing="0" cellpadding="2">
						<tr>
							{assign var="col2" value="1"} 
							{foreach from=$CUISINES.items item=cuisines}
								<td width="148"><a href="#" class="normal_blicklink" onClick="javascript:searchCuisine('{$cuisines.item_id}');">{$cuisines.item_name}</a></td>
							{if $col2%4 eq 0}	
						</tr>
						{/if}
						{assign var="col2" value="`$col2+1`"} 
						{/foreach}
						</tr>
						<tr>
							<td>
							<form name="frm_cuisine" method="post" action="">
							<input type="hidden" name="cuisine_id" value="">
							<input type="hidden" name="txt_city" value="{$smarty.request.txt_city}">
							<input type="hidden" name="txt_restaurant" value="{$smarty.request.txt_restaurant}">
							<input type="hidden" name="hid_basic_search" value="{$smarty.request.hid_basic_search}">
							
							</form>
							</td>
							<td>&nbsp;</td>
							<td>&nbsp;</td>
							<td><a href="#" class="normal_redlink" onClick="javascript:searchCuisine('NoCuisine');">View All Cuisines</a></td>
						</tr>
						</table>
							</div>
					</div>
				    <div class="cuisine_wrap_bottom"><!-- --></div>
			</div>
			<div class="clear"></div>
			
			<!--Banner bottom BOX -->
			<div style="padding-top:10px;">
				<div class="right_top"><!-- --></div>
				<div class="right_bg">
				<div  style="height:80px;padding-left:70px; padding-top:15px;">{$BANNER_ADS6}<!-- <img src="{$GLOBAL.tpl_url}/images/banner_botm.jpg" alt="" width="471" height="62" /> --></div>
				
				<div class="clear"></div>
				</div>
				<div class="right_bottom"><!-- --></div>
			</div>
<!--Banner bottom BOX -->			
		</div>
		<!-- END:Right Wrap-->
		<div class="clear"></div>
	</div>