{literal}
<script language="javascript">
function submitDetails()
{
		document.frm_package.submit();
}

</script>
{/literal}
<div id="right_wrap">
			<div class="ad_wrap01"><!-- <img src="{$GLOBAL.tpl_url}/images/adimg.jpg" alt="" width="728" height="90" /> -->{$GADD}</div>
			
			<div class="padding08">
				<div style="width:750px; float:left; ">
				<div class="profile_wrap02">
					<div class="profile_wrap_top02"><!-- --></div>
					
				  <div class="profile_wrap_inner02">
					 <div class="profile02_container">
					<div class="page_nav" style="height:34px;">
						<a href="#">Home</a> <span class="nav_img"></span> <a href="#">Restauranteurs</a><a href="#"></a>
						<div class="clear"></div>
					   </div>
						<div class="head04">{$MOD_VARIABLES.MOD_LABELS.LBL_SELECT_PACK}</div>
					   <form name="frm_package" method="post" action="">
					    <div class="padding07">
					      <div class="padding01">
						 <table width="100%" border="0" cellspacing="0" cellpadding="0">
 {foreach from=$PACKAGES item=pack}
  <tr>
    <td width="12%" align="right" valign="top"><input name="package_id" type="radio" value="{$pack.id}"  checked/>    </td>
    <td width="2%">&nbsp;</td>
    <td width="86%" align="left" valign="top" class="head01">{$pack.name}</td>
  </tr>
  <tr>
    <td align="right" valign="top">&nbsp;</td>
    <td>&nbsp;</td>
    <td align="left" valign="top">&nbsp;</td>
  </tr>
  {/foreach}
 
</table>

						 
						 </div>
						
						 
						   <div class="padding07">
						   <div class="form_row_field">
					       <div class="message_holder" style=" height:150px;"></div>
						   <table width="100%" border="0" cellspacing="0" cellpadding="0">
                        
                             <tr>
                               <td width="26%">&nbsp;</td>
                               <td width="74%" align="left" valign="middle"><a class="top_btn" href="#" onClick="javascript:submitDetails();"><span>{$MOD_VARIABLES.MOD_BUTTONS.BUTTON_NEXT} </span></a></td>
                             </tr>
							   <tr>
                               <td>&nbsp;</td>
                               <td align="left" valign="middle">&nbsp;</td>
                             </tr>
                           </table>
					     </div>
					      </div>
					      <div class="form_row_field"></div>
						</div>
						</form>
						
						
						
						<!-- end of payment gateway integration -->
						
						
					    <div class="clear"></div>
				    </div>
				  </div>
				  
					<div class="profile_wrap_bottom02"><!-- --></div>
					
				</div>	
				<div class="clear"></div>
				<div class="padding08"><!-- --></div>			
				</div>
				<div class="clear"></div>
			</div>
			
		
		</div>