<div class="coupon02">
  <table width="100%" border="0" cellspacing="0" cellpadding="5">
    <tr>
      <td height="35"><div align="center"><img src="{$GLOBAL.tpl_url}/images/logo_coupon.jpg" alt="" width="177" height="67" /></div></td>
    </tr>
    <tr>
      <td height="35" class="coupon_head">{$COUPON_DETAILS.name}</td>
    </tr>
    <tr>
      <td height="170" align="left" valign="top"><table width="100%" border="0" cellspacing="0" cellpadding="0">
        <tr>
          <td width="33%" height="30" align="left" valign="middle">Valid</td>
          <td width="67%"> {$COUPON_DETAILS.valid_from|date_format:"%B %e %Y"} &nbsp;-&nbsp; {$COUPON_DETAILS.valid_to|date_format:"%B %e %Y"}</td>
        </tr>
       <!--  <tr>
          <td height="30">Days Available </td>
          <td align="left" valign="middle">Any day of the week </td>
        </tr> -->
        <tr>
          <td height="30">Time Available </td>
          <td align="left" valign="middle">{$COUPON_DETAILS.time_avilable_from|date_format:"%r "}&nbsp;- &nbsp;{$COUPON_DETAILS.time_avilable_to|date_format:"%r"} </td>
        </tr>
		  <tr>
									<td height="30">Offer </td>
									<td align="left" valign="middle">{if $COUPON_DETAILS.price ne ''}{$COUPON_DETAILS.price} {if $COUPON_DETAILS.discount eq Price}${else}%{/if}{/if}</td>
								  </tr>
								   <tr>
									
									<td align="left" valign="middle" colspan="2"  height="20">{$COUPON_DETAILS.offer_description}</td>
								  </tr>
								
								   <tr>
								    <td height="10" colspan="2" class="red_bold">{$COUPON_DETAILS.title},
                                      <span>{$COUPON_DETAILS.location_city|lower|capitalize},{$COUPON_DETAILS.location_zip}</span></td>
							      </tr>
								   <tr>
								    <td height="10" colspan="2" class="red_bold">{$COUPON_DETAILS.contact_phone}</td>
							      </tr>
      </table></td>
    </tr>
    <tr>
      <td height="55" align="left" valign="top" class="coupon_rule"><span>Rules: </span>{$COUPON_DETAILS.rules}</td>
    </tr>
  </table>
</div>
<div style="margin-bottom:10px;"></div>