<div id="mid_wrap">
	 <div class="terms_wrap">
	 <h2>All Cities</h2>
	 <div class="pad15">
	
	  
	  
	  <!--Listing Start -->
	  {foreach from =$CITIES item=state}
	 <div class="sub_title"><a href="#">{$state.location_state}</a></div>
	 <div class="citylist">
	 
	 <table width="99%" border="0" cellspacing="0" cellpadding="0">
            
                   <tr >
					 {assign var="col2" value="1"} 
					 {foreach from=$state.city item=cities}
                      <td width="126" align="left" valign="top" class="citylist_class"><a href="{makeLink mod=flyer pg=list}act=search&hid_advanced_search=Y&location_city={$cities.location_city}{/makeLink}">{$cities.location_city}</a></td>
					  {if $col2%5 eq 0}	
                      </tr>
					  {/if}
					 {assign var="col2" value="`$col2+1`"} 
					   {/foreach}
                    </tr>
                 </table>
	 </div>
	<!-- <div class="citylist">
	
	 <ul>
	{assign var="col2" value="1"} 
	{foreach from=$state.city item=cities}
		<li><a href="#">re{$cities.location_city}</a></li>
		{if $col2%5 eq 0}	
			</ul>
		{/if}
		{assign var="col2" value="`$col2+1`"} 
	{/foreach}
		</ul> 
	 
	 <div class="clear"></div>
	 </div> -->
	 {/foreach}
	  <!--Listing End -->
	  
	  <!--Listing End -->
      <!-- -->
     </div>
	 </div>
  </div>