{literal}
<script language="javascript">
function submitCoupons()
{
	if(document.frm_coupon.name.value=='')
	{
		alert('Please enter Name');
		return false;
	}
	else
	{
		document.frm_coupon.submit();
	}
}

</script>
{/literal}
<form name="frm_coupon" method="post" action="">
<div id="right_wrap">
			<div class="ad_wrap01">{$GADD}<!-- <img src="{$GLOBAL.tpl_url}/images/adimg.jpg" alt="" width="728" height="90" /> --></div>
			
			<div class="padding08">
				<div style="width:750px; float:left; ">
				<div class="profile_wrap02">
					<div class="profile_wrap_top02"><!-- --></div>
					
				  <div class="profile_wrap_inner02">
					 <div class="profile02_container">
					<div class="page_nav" style="height:34px;">
						<a href="#">Home</a> <span class="nav_img"></span> <a href="#">Create Coupons</a><a href="#"></a>
						<div class="clear"></div>
					   </div>
						<div class="head04">Create Coupons </div>
					    <div class="padding07">
					     <div class="form_row_field">
							<div class="form_wrap_field">
								<div class="name_wrap_field"> Headline </div>
							  <div class="field_wrap_form"><input type="text" name="name" class="text_field_form" style="width:200px;" value="" />
							  </div>
							</div>
							<div class="message_holder" style="display:;"></div>
						</div>
						
						<div class="form_row_field">
							<div class="form_wrap_field" >
								<div class="name_wrap_field">Valid From </div>
							  <div class="field_wrap_form">
							    <table width="235" border="0" cellspacing="0" cellpadding="0">
                                  <tr>
								  <td>
								  {html_select_date prefix="valid_from_" time=$time start_year=$smarty.request.Expiry_Year|default:"+0" end_year="+10" display_days=true }
								  </td>
                                             </tr>
                                </table>
							  </div>
							</div>
							<div class="message_holder" style="display:none;">
								<div class="error_message">
								Error Message goes Here
								</div>
							</div>
						</div>
						
						<div class="form_row_field">
							<div class="form_wrap_field" >
								<div class="name_wrap_field">Valid To </div>
							  <div class="field_wrap_form">
							    <table width="235" border="0" cellspacing="0" cellpadding="0">
                                  <tr>
								   <td>
								  {html_select_date prefix="valid_to_" time=$time start_year=$smarty.request.Expiry_Year|default:"+0" end_year="+10" display_days=true }
								  </td>
                          
                                  </tr>
                                </table>
							  </div>
							</div>
							<div class="message_holder" style="display:none;">
								<div class="error_message">
								Error Message goes Here
								</div>
							</div>
						</div>
						
						<div class="form_row_field">
							<div class="form_wrap_field" >
								<div class="name_wrap_field">Time Available From </div>
						      <div class="field_wrap_form">
						        <table width="235" border="0" cellspacing="0" cellpadding="0">
                                  <tr>
                                       <td >{html_select_time use_24_hours=false display_minutes=false display_seconds=false prefix=time_from}</td>
                                  </tr>
                                </table>
						      </div>
							</div>
							<div class="message_holder" style="display:none;">
								<div class="error_message">
								Error Message goes Here
								</div>
							</div>
						</div>
						
						<div class="form_row_field">
							<div class="form_wrap_field" >
								<div class="name_wrap_field">Time Available To </div>
						        <div class="field_wrap_form">
						        <table width="235" border="0" cellspacing="0" cellpadding="0">
                                  <tr>
                                              <td >{html_select_time use_24_hours=false display_minutes=false display_seconds=false prefix=time_to}</td>
                                  </tr>
                                </table>
						      </div>
							</div>
							<div class="message_holder" style="display:none;">
								<div class="error_message">
								Error Message goes Here
								</div>
							</div>
						</div>
						
						
						  
						  
						  
						
						<div class="form_row_field1">
							<div class="form_wrap_field" >
								<div class="name_wrap_field">Rules</div>
								<div class="field_wrap_form">
								  <label>
								  <textarea name="rules" class="text_area" style="width:200px;height:100px;"></textarea>
								  </label>
								</div>
							</div>
							<div class="message_holder" style="display:none;">
								<div class="error_message">
								Error Message goes Here
								</div>
							</div>
						</div>
						<div class="form_row_field">
						  <table width="363" border="0" align="left" cellpadding="0" cellspacing="0">
                            <tr>
                              <td width="153">&nbsp;</td>
                              <td width="210">
							  <input type="hidden" name="flyer_id" value="{$smarty.request.flyer_id}">
							  <a class="top_btn" href="#"  onClick="javascript:submitCoupons();"><span>Create Coupons</span></a></td>
                            </tr>
                          </table>
						</div>
						<div  style="padding-top:106px;"></div>			
				  </div>
				  <div class="clear"></div>
				    </div>
				  </div>
					<div class="profile_wrap_bottom02"><!-- --></div>
					
				</div>	
				<div class="clear"></div>
				<div class="padding08"><!-- --></div>			
				</div>
				<div class="clear"></div>
			</div>
			
		
		</div>
</form>