{literal}
<script language="javascript">
function submitDetails()
{
	if(document.frm_package.transation_code.value=='')
	{
		alert('Please enter transation code');
		return false;
	}
	else if(document.frm_package.amount.value=='')
	{
		alert('Please enter amount');
		return false;
	}
	else
	{
		document.frm_package.submit();
	}
}
function submitPaymentDetails()
{
	if(document.frm_payments.transation_code.value=='')
	{
		alert('Please enter Name on Card');
		return false;
	}
	else if(document.frm_payments.creditCard.value=='')
	{
		alert('Please enter Card Number');
		return false;
	}
	else if(document.frm_payments.cvc.value=='')
	{
		alert('Please enter CVV Code');
		return false;
	}
	else
	{
		document.frm_payments.hid_creditcard_payment.value	='Y';
		document.frm_payments.submit();
	}
}
</script>
{/literal}
<div id="right_wrap">
			<div class="ad_wrap01"><!-- <img src="{$GLOBAL.tpl_url}/images/adimg.jpg" alt="" width="728" height="90" /> -->{$GADD}</div>
			
			<div class="padding08">
				<div style="width:750px; float:left; ">
				<div class="profile_wrap02">
					<div class="profile_wrap_top02"><!-- --></div>
					
				  <div class="profile_wrap_inner02">
					 <div class="profile02_container">
					<div class="page_nav" style="height:34px;">
						<a href="#">Home</a> <span class="nav_img"></span> <a href="#">Restauranteurs </a><a href="#"></a>
						<div class="clear"></div>
					   </div>
						{if $smarty.session.member_type ne '2'}
					   <form name="frm_package" method="post" action="">
					    <div class="padding07">
					      <div class="head04">{$MOD_VARIABLES.MOD_LABELS.LBL_ENTER_PAYMENTDETAILS}</div>
						 
						   <div class="padding07">
						   <div class="form_row_field">
					       <div class="message_holder" style=" height:150px;"></div>
						   <table width="100%" border="0" cellspacing="0" cellpadding="0">
                             <tr>
                               <td width="26%">{$MOD_VARIABLES.MOD_LABELS.LBL_TRANSATION_CODE} </td>
                               <td width="74%" align="left" valign="middle"><span class="field_wrap_form">
                                 <input name="transation_code" type="text" class="text_field_form" style="width:200px;" />
                               </span></td>
                             </tr>
                             <tr>
                               <td>&nbsp;</td>
                               <td align="left" valign="middle">&nbsp;</td>
                             </tr>
                             <tr>
                               <td>{$MOD_VARIABLES.MOD_LABELS.LBL_TRANSATION_AMOUNT} </td>
                               <td align="left" valign="middle"><span class="field_wrap_form">
                                 <input name="amount" type="text" class="text_field_form" style="width:200px;" />
								 <input type="hidden" name="restauranteur_id" value="{$smarty.request.restauranteur_id}">
								 <input type="hidden" name="flyer_id" value="{$smarty.request.flyer_id}">
                               </span></td>
                             </tr>
                             <tr>
                               <td>&nbsp;</td>
                               <td align="left" valign="middle">&nbsp;</td>
                             </tr>
                        
                             <tr>
                               <td>&nbsp;</td>
                               <td align="left" valign="middle"><a class="top_btn" href="#" onClick="javascript:submitDetails();"><span>{$MOD_VARIABLES.MOD_BUTTONS.BUTTON_NEXT} </span></a></td>
                             </tr>
							   <tr>
                               <td>&nbsp;</td>
                               <td align="left" valign="middle">&nbsp;</td>
                             </tr>
                           </table>
					     </div>
					      </div>
					      <div class="form_row_field"></div>
						</div>
					   </form>
						
						{else}
						<!-- payment gateway integration -->
						<form name="frm_payments" method="post" action="">
								<div class="padding07">
								<div class="head04">{$MOD_VARIABLES.MOD_LABELS.LBL_ENTER_PAYMENTDETAILS}</div>
								
								<div class="padding07">
								<div class="form_row_field">
								<div class="message_holder" style=" height:250px;"></div>
								<table width="100%" border="0" cellspacing="0" cellpadding="0">
								<tr>
								<td width="26%"><!-- {$MOD_VARIABLES.MOD_LABELS.LBL_TRANSATION_CODE} --> Credit Card Type </td>
								<td width="74%" align="left" valign="middle"><span class="field_wrap_form">
								<select name="card_type" align="left" class="list_field_form"  style="width:220px;">
								{html_options values=$CREDITCARD.name output=$CREDITCARD.name selected=$smarty.request.card_type}
                     			 </select>
								</span></td>
								</tr>
								<tr>
								<td>&nbsp;</td>
								<td align="left" valign="middle">&nbsp;</td>
								</tr>
								<tr>
								<td width="26%"><!-- {$MOD_VARIABLES.MOD_LABELS.LBL_TRANSATION_CODE} --> Name on Card</td>
								<td width="74%" align="left" valign="middle"><span class="field_wrap_form">
								<input name="transation_code" type="text" class="text_field_form" style="width:200px;" />
								</span></td>
								</tr>
								<tr>
								<td>&nbsp;</td>
								<td align="left" valign="middle">&nbsp;</td>
								</tr>
								<tr>
								<td width="26%"><!-- {$MOD_VARIABLES.MOD_LABELS.LBL_TRANSATION_CODE} -->Card Number </td>
								<td width="74%" align="left" valign="middle"><span class="field_wrap_form">
								<input type="text" name="creditCard" size="30" value="{$smarty.request.creditCard}" class="text_field_form" style="width:200px;" maxlength="20"/>
								</span></td>
								</tr>
								<tr>
								<td>&nbsp;</td>
								<td align="left" valign="middle">&nbsp;</td>
								</tr>
								<tr>
								<td width="26%"><!-- {$MOD_VARIABLES.MOD_LABELS.LBL_TRANSATION_CODE} -->Expiry date  </td>
								<td width="74%" align="left" valign="middle"><span class="field_wrap_form" class="list_field_form">
								 {html_select_date prefix="Expiry_" time=$time start_year=$smarty.request.Expiry_Year|default:"+0" end_year="+10" display_days=false }
								</span></td>
								</tr>
								<tr>
								<td>&nbsp;</td>
								<td align="left" valign="middle">&nbsp;</td>
								</tr>
								<tr>
								<td width="26%"><!-- {$MOD_VARIABLES.MOD_LABELS.LBL_TRANSATION_CODE} --> CVV Code</td>
								<td width="74%" align="left" valign="middle"><span class="field_wrap_form">
								<input type="text" name="cvc" size="5" value="{$smarty.request.cvc}" class="text_field_form" style="width:100px;" maxlength="6"/>
								</span></td>
								</tr>
								<tr>
								<td>&nbsp;</td>
								<td align="left" valign="middle">&nbsp;</td>
								</tr>
								
								
								<tr>
								<td>&nbsp;</td>
								<td align="left" valign="middle">
								<input type="hidden" name="hid_creditcard_payment" value="N">
								<a class="top_btn" href="#" onClick="javascript:submitPaymentDetails();"><span>{$MOD_VARIABLES.MOD_BUTTONS.BUTTON_NEXT} </span></a></td>
								</tr>
								<tr>
								<td>&nbsp;</td>
								<td align="left" valign="middle">&nbsp;</td>
								</tr>
								</table>
								</div>
								</div>
								<div class="form_row_field"></div>
						  </div>
						</form>
						{/if}
						
						<!-- end of payment gateway integration -->
						
						
					    <div class="clear"></div>
				    </div>
				  </div>
				  
					<div class="profile_wrap_bottom02"><!-- --></div>
					
				</div>	
				<div class="clear"></div>
				<div class="padding08"><!-- --></div>			
				</div>
				<div class="clear"></div>
			</div>
			
		
		</div>