<div id="inner_mid" style="padding-bottom:0px;">
		<!-- START:Left Wrap-->
		<div id="left_wrap">
		
		
		
			<!-- START:Profile Wrap-->
			<!-- END:Profile Wrap-->
            <!-- START:Profile Wrap-->
<div class="box_wrap">
			
				<div class="box_wrap_top"><!-- --></div>				
			  <div class="box_wrap_inner" style="padding:0px 0px 0px 10px;">
					
					<div class="">
							
					  <span class="head_style01 headstyle_padding">{$COM_VARIABLES.MOD_LABELS.LBL_HOME_RECENT}</span>
					  
					   <span class="padding02"><!-- --></span>
					   
					    {foreach from=$RECENT_RESTAURANTS item=recent}
					  <div class="raw01" style="width:170px;"><span class="raw01"><a  href="{makeLink mod=flyer pg=list}act=flyer_details&flyer_id={$recent.flyer_id}{/makeLink}" border="0">
						{if $recent.image ne ''} 
              	 <img src="{$GLOBAL.modbase_url}/flyer/images/widget/thumb/{$recent.image}" alt="{$recent.title}"  class="img_style"/>
				{else}
				 <img src="{$GLOBAL.modbase_url}/flyer/images/widget/thumb/default.jpg" alt="{$recent.title}"  class="img_style"/>
				{/if}</a></span>
					  <div class="raw01_content" style="width:110px;">
					    <table width="110" border="0" cellspacing="0" cellpadding="0">
					      <tr>
					        <td align="left" valign="top"><span class="normal_bold"><a  href="{makeLink mod=flyer pg=list}act=flyer_details&flyer_id={$recent.flyer_id}{/makeLink}" class="normal_bold">{$recent.title|truncate:25}</a></span><br />
				            {$recent.location_city}&nbsp; {$recent.location_zip} </td>
                          </tr>
					      
				        </table>
					  </div>
						      <div class="clear"></div>
						  
				  </div>
				   <span class="line_bg" style="padding-top:0px;"><!-- --></span>
				   {/foreach}
				   
								  
			  </div>
				
					
			  </div>
				<div class="box_wrap_btm"><!-- --></div>
		  </div>
			<!-- END:Profile Wrap-->
			<div class="padding08"><!-- --></div>
			<!-- START:Profile Wrap-->
			<div class="box_wrap">
				<div class="box_wrap_top"><!-- --></div>
				<div class="box_wrap_inner" style="padding:0px 0px 0px 10px;">
					
					<div class="">
							
					  <span class="head_style01 headstyle_padding">Special Offers &amp; Coupons</span>
					  
					   <span class="padding02"><!-- --></span>
					   {foreach from=$HOME_COUPONS item=latest_coupons}
					   <div class="raw01" style="width:170px;"><span class="raw01">
					   <a  href="{makeLink mod=flyer pg=list}act=coupons&flyer_id={$latest_coupons.flyer_id}{/makeLink}" border="0">
						{if $latest_coupons.image ne ''} 
						 <img src="{$GLOBAL.modbase_url}/flyer/images/widget/thumb/{$latest_coupons.image}" alt="{$latest_coupons.title}"  class="img_style"/>
						{else}
						 <img src="{$GLOBAL.modbase_url}/flyer/images/widget/thumb/default.jpg" alt="{$latest_coupons.title}"  class="img_style"/>
						{/if}</a>
					   </span>
					  <div class="raw01_content" style="width:110px;">
					    <table width="110" border="0" cellspacing="0" cellpadding="0">
					      <tr>
					        <td align="left" valign="top"><span class="normal_bold"><a  href="{makeLink mod=flyer pg=list}act=coupons&flyer_id={$latest_coupons.flyer_id}{/makeLink}" border="0" class="normal_bold">{$latest_coupons.title|truncate:20}</a></span><br />
				           {$latest_coupons.description|truncate:50}</td>
                          </tr>
					      
				        </table>
					  </div>
						      <div class="clear"></div>
						  
				  </div>
				   <span class="line_bg" style="padding-top:0px;"><!-- --></span>
				   {/foreach}
				   
				  <div class="padding02" style="text-align:left" ><a href="#" class="normal_redlink_bold1">More Details</a></div>
				  
			  </div>
				
					
			  </div>
				<div class="box_wrap_btm"><!-- --></div>
			</div>
			<!-- END:Profile Wrap-->
			<div class="padding08"><!-- --></div>
			<!-- START:Profile Wrap-->
			<div class="box_wrap">
				<div class="box_wrap_top"><!-- --></div>
				<div class="box_wrap_inner" style="padding:0px;">
				
					<div style="text-align:center;">{$GADD3}</div>
					
				
					
				</div>
				<div class="box_wrap_btm"><!-- --></div>
			</div>
			<!-- END:Profile Wrap-->
			<div class="padding08"><!-- --></div>
			
			
	  </div>
		<!-- END:Left Wrap-->
		
		<!-- START:Right Wrap-->
		<div id="right_wrap">
			<div class="ad_wrap01">{$GADD}</div>
			
			<div class="padding08">
				<div style="width:432px; float:left;">
				
				<!--CITIES -->
				<!--CITIES END -->
<div class="couponlist_wrap">
				<div class="couponlist_wrap_top"><!-- --></div>
				<div class="couponlist_wrap_inner">
				<div class="page_nav">
				<a href="#">Home</a> <span class="nav_img"></span> <a href="#">Coupons</a><a href="#"></a>
				<div class="clear"></div>
				<span class="head_style01">Coupons Results </span>
				<span class="head_style04 padding_10" style="text-align:right; float:right;">Results {$RESULT_START}-{$LIMIT} of {$COUPON_COUNT} </span>
				</div>
				<br clear="all" />
					<div style="padding-top:15px;">
					
					<!--Coupon List -->
					{foreach from=$COUPON_LIST item=coupons } 
					<div class="coupon">
					<table width="100%" border="0" cellspacing="0" cellpadding="5">
							  <tr>
								<td height="35" class="coupon_head">{$coupons->name}</td>
							  </tr>
							  <tr>
								<td height="150" align="left" valign="top"><table width="100%" border="0" cellspacing="0" cellpadding="0">
								  <tr>
									<td width="41%" height="30" align="left" valign="middle">Valid</td>
									<td width="59%">{$coupons->valid_from|date_format:"%B %e %Y"} &nbsp;-&nbsp; {$coupons->valid_to|date_format:"%B %e %Y"} </td>
								  </tr>
								
								  <tr>
									<td height="30">Time Available </td>
									<td align="left" valign="middle">{$coupons->time_avilable_from|date_format:"%r "}&nbsp;- &nbsp;{$coupons->time_avilable_to|date_format:"%r"} </td>
								  </tr>
								   <tr>
									<td height="30">Offer </td>
									<td align="left" valign="middle">{if $coupons->price ne ''}{$coupons->price} {if $coupons->discount eq Price}${else}%{/if}{/if}</td>
								  </tr>
								   <tr>
									
									<td align="left" valign="middle" colspan="2"  height="20">{$coupons->offer_description}</td>
								  </tr>
								
								   <tr>
								    <td height="10" colspan="2" class="red_bold">{$coupons->title},
                                      <span>{$coupons->location_city|lower|capitalize},{$coupons->location_zip}</span></td>
							      </tr>
								   <tr>
								    <td height="10" colspan="2" class="red_bold">{$coupons->contact_phone}</td>
							      </tr>
								</table></td>
							  </tr>
							  <tr>
								<td height="2" align="left" valign="top" class="coupon_rule"><span>Rules: </span>{$coupons->rules}</td>
							  </tr> 
							  <!--  <tr>
								<td height="55" align="left" valign="top" class="coupon_rule"><span>Offer Description: </span>{$coupons->offer_description}</td>
							  </tr>  -->
							 <!--   <tr>
								<td height="55" align="left" valign="top" class="coupon_rule"><span>Price: </span>{$coupons->price}</td>
							  </tr>  -->
							  <!--  <tr>
								<td height="55" align="left" valign="top" class="coupon_rule"><span>Address & Phone </span>{$coupons->address}</td>
							  </tr>  -->
							   <tr>
							    <td height="30" align="left" valign="top" ><table width="100%" border="0" align="right" cellpadding="0" cellspacing="0">
                                  <tr>
                                    <td width="113" class="print"><a href="{makeLink mod=flyer pg=list}act=coupon_details&coupon_id={$coupons->id}{/makeLink}">Print this page</a></td>
                                    <td width="123" class="reservation"><a href="{makeLink mod=flyer pg=list}act=flyer_details&flyer_id={$coupons->flyer_id}{/makeLink}">View Restaurant</a></td>
                                    <td width="137" class="reservation"><!-- <a href="{makeLink mod=flyer pg=list}act=reservation&flyer_id={$coupons->flyer_id}{/makeLink}">Make a reservation</a> --></td>
                                  </tr>
                                </table></td>
				      </tr>   
					</table>
			  		</div>
					{/foreach}
					<!--End : Coupon list -->
					<div align="right">
					<span class="paging_nav"> 	{$COUPON_NUMPAD}</span></div>
					</div>		
						
				</div>
				</div>
					<div class="couponlist_wrap_bottom"><!-- --></div>
					
			  </div>
				
				<div class="listright_wrap" style="width:287px;">
					<!--Featured Restaurent -->
          <div class="featured_wrap" >
			<div class="block_wrap_top" style="padding-bottom:10px;"><!-- --></div>
			<div class="head01 head_bg"> Featured Restaurant</div>
				
				<div class="block_inner text01 " >
					<div style="height:180px;">
					
					<span class="normal_bold"><a  href="{makeLink mod=flyer pg=list}act=flyer_details&flyer_id={$FEATURED_RESTAURANT.flyer_id}{/makeLink}" class="normal_bold">{$FEATURED_RESTAURANT.title|truncate:25}</a></span><br />
					{$FEATURED_RESTAURANT.location_state} &nbsp;{$FEATURED_RESTAURANT.location_city} &nbsp;{if $FEATURED_RESTAURANT.location_zip ne ''}, {$FEATURED_RESTAURANT.location_zip}{/if}
					</span>
					
					
					<p>{$FEATURED_RESTAURANT.description|truncate:320}</p>
					{if $FEATURED_RESTAURANT.title ne ''}
					<table width="265" border="0" cellspacing="0" cellpadding="0">
  
  <tr>
    <td height="19" class="normal_bold1">{$COM_VARIABLES.MOD_LABELS.LBL_HOME_RATING}</td>
    <td class="normal_bold1">{$COM_VARIABLES.MOD_LABELS.LBL_HOME_PRICING}</td>
  </tr>
  <tr>
    <td height="25">{if $FEATURED_RESTAURANT.title ne ''}{if $FEATURED_RESTAURANT.rate ne ''}<img src="{$GLOBAL.tpl_url}/images/rate{$FEATURED_RESTAURANT.rate}.gif"  />{else}<img src="{$GLOBAL.tpl_url}/images/rate0.gif"  /> {/if}{/if}</td>
    <td>{if $FEATURED_RESTAURANT.title ne ''}{if $FEATURED_RESTAURANT.price ne ''}<img src="{$GLOBAL.tpl_url}/images/price{$FEATURED_RESTAURANT.price}.gif"  />{else}<img src="{$GLOBAL.tpl_url}/images/price0.gif"  /> {/if}{/if}</td>
  </tr>
</table>{/if}<div class="clear"></div>
</div>
			<div class="padding02" style="width:280px; height:230px; ">
			
			{if $FEATURED_RESTAURANT.video_code ne ''}
				{$FEATURED_RESTAURANT.video_code} 
			{/if}
			
			</div>
			<div class="link_block_height"><!-- --></div>
			{if $FEATURED_RESTAURANT.title ne ''}
			<div class="link_block">
			
			  <table width="265" border="0" cellspacing="0" cellpadding="2">
                <tr>
                  <td width="20" height="18"><img src="{$GLOBAL.tpl_url}/images/email_icon.jpg" alt="" width="17" height="17" /></td>
                  <td width="93"><a href="{makeLink mod=flyer pg=list}act=flyer_details&flyer_id={$FEATURED_RESTAURANT.flyer_id}{/makeLink}" class="small_text_link">{$COM_VARIABLES.MOD_LABELS.LBL_HOME_EMAIL_FRND}</a></td>
                  <td width="22"><img src="{$GLOBAL.tpl_url}/images/add_wish_list.jpg" width="17" height="17" /></td>
                  <td width="114"><a href="{makeLink mod=flyer pg=list}act=flyer_details&flyer_id={$FEATURED_RESTAURANT.flyer_id}{/makeLink}" class="small_text_link">{$COM_VARIABLES.MOD_LABELS.LBL_HOME_ADD_WISHLIST} </a></td>
                </tr>
                <tr>
                  <td><img src="{$GLOBAL.tpl_url}/images/reviw_icon.jpg" width="17" height="17" /></td>
                  <td><a href="{makeLink mod=flyer pg=list}act=flyer_details&flyer_id={$FEATURED_RESTAURANT.flyer_id}{/makeLink}" class="small_text_link">{$COM_VARIABLES.MOD_LABELS.LBL_HOME_WRITE_REVIEW} </a></td>
                  <td><img src="{$GLOBAL.tpl_url}/images/add_fav.jpg" width="17" height="17" /></td>
                  <td><a href="{makeLink mod=flyer pg=list}act=flyer_details&flyer_id={$FEATURED_RESTAURANT.flyer_id}{/makeLink}" class="small_text_link">{$COM_VARIABLES.MOD_LABELS.LBL_HOME_ADD_FAVORITE}</a></td>
                </tr>
              </table>
			</div>
 {/if}
				</div>
				
				
			<div class="block_wrap_bottom"><!-- --></div>
		</div>
		  <!--Featured Restaurent -->
		  
					<div class="clear"></div>
					<div class="padding_09"><!-- --></div>
					<div class="block_wrap padding_none">
                      <div class="block_wrap_top">
                        <!-- -->
                      </div>
					  <div class="block_inner padding_08" align="center">{$BANNER_ADS4}</div>
					  <div class="block_wrap_bottom">
					    <!-- -->
				      </div>
				  </div>
				</div>
				
				<div class="clear"></div>
			</div>
			
		
		</div>
		<!-- END:Right Wrap-->
		
		
		<br clear="all" />
	</div>