<script language="javascript" type="text/javascript">
// <![CDATA[
var SITE_URL_JS		=	"{$smarty.const.SITE_URL}";
var QUERY_DEST_JS	=	'{$qryDest}';
var backgroundimg 	= 	"{$smarty.const.SITE_URL}/includes/map/icons/marker.png";
var overlayimg 		=   "{$smarty.const.SITE_URL}/includes/map/icons/num";
var CityMarkCent;
var polyCirc;
// ]]>
</script>
<SCRIPT LANGUAGE="JavaScript" TYPE="text/javascript" src="{$smarty.const.SITE_URL}/includes/ajax/ajax.js"></script>
<link href="{$smarty.const.SITE_URL}/includes/map/map.css" rel="stylesheet" type="text/css">
<script language="javascript" type="text/javascript" src="{$smarty.const.SITE_URL}/includes/map/mainjs.js"></script>
{literal}
<style type="text/css">
      @import url("http://www.google.com/uds/css/gsearch.css");
      @import url("http://www.google.com/uds/solutions/localsearch/gmlocalsearch.css");
</style>
<style type="text/css">
#noclick {
	opacity: 0.7;
	filter:alpha(opacity=50);
	-moz-opacity: 0.7;
	-khtml-opacity: 0.7;
	width:100%;
	height:100%;
	position:absolute;
	display:none;
	background:#000000;
	z-index:2500;
	left:0;
	top:0;
}
</style>

<script language="javascript">

function load() {
var xmlStr 		= '{/literal}{$xmlStr}{literal}';


		SetMapProperty(true,true);
		document.getElementById('mapContainer').style.display='none';
		document.getElementById('property_map_add').style.visibility='visible';

//document.getElementById('errMsg').style.display='none'
		{/literal}{if $mapSetPosStr} {literal}
		SetMapCoordpopUp ({/literal}{$mapSetPosStr},'{$popStr}','',false{literal});
		{/literal}{else}{literal}
		setMarkerPositionpopUp ({/literal}'{$query}','{$popStr}','',false{literal});  //$mapSetPosStr
		verifyAddressprivate({/literal}'{$query}','{$popStr}'{literal});
		{/literal}{/if}{literal}
		
        
		
		
		if ( trim( xmlStr ) ) {
	  var xml = GXml.parse(xmlStr);
	  var markers = xml.documentElement.getElementsByTagName("marker");
	  for (var i = 0; i < markers.length; i++) {
	
			
		var title 		 = markers[i].getAttribute("name");
		var address		 = markers[i].getAttribute("address"); 
		var description	 = markers[i].getAttribute("description"); 
		
		var point 		 = new GLatLng(parseFloat(markers[i].getAttribute("lat")),
								parseFloat(markers[i].getAttribute("lng")));
								
							
	
		var marker = createMarker(point, title, address,description,i+1);
		 
		map.addOverlay(marker);
		
	}
	
	}
		
		
		
		
		
			
		
		
	}
	
	

	function serverRese1(_var) {
		_var = _var.split('|');
		if (_var[0]) {
			setMarkerPositionpopUp ({/literal}'{$query}','{$popStr}','',true{literal});  //$mapSetPosStr
		}
	}

	function ClearMapLocation () {
		var PropertyID = document.getElementById('hid_album_id').value;
		var req1  = newXMLHttpRequest();
		req1.onreadystatechange = getReadyStateHandler(req1, serverRese1);
		str		  = "album_ID="+PropertyID;
{/literal}
		req1.open("POST", "{makeLink mod=flyer pg=list}act=deleteAlbumMapPos{/makeLink}&"+Math.random());
{literal}
		req1.setRequestHeader("Content-Type","application/x-www-form-urlencoded; charset=UTF-8");
		req1.send(str);
	}
	
	
	function verifyAddressprivate(address) {
		  if (geocoder) {
				geocoder.getLatLng( address, function(point) {
					if (!point) {
						document.getElementById('errMsg').style.display='inline';
					} else {
						return true;
					}
				  }
				 );
		  }
    }










function popUpHtmlBlockMap(lat,lon,CONT){
	
	  var CURRPONT 		 = new GLatLng(parseFloat(lat),
										parseFloat(lon));
		 map.openInfoWindowHtml(CURRPONT,CONT);
		 map.setCenter(CURRPONT);
	 
}





















function AddtoFilter(item_id,item_name,div_name)
{
	if(document.getElementById('div_selected_filter_box').style.display	==	'none')
	{
		document.getElementById('div_selected_filter_box').style.display	=	'block';
	}
	var selectedFilter	=	'div_seleted_filter_' + item_id;
	var	CurrentFilter	=	document.getElementById('div_selected_filters').innerHTML;
	var newFilter		=	'<div class="filter_link" id="div_seleted_filter_'+item_id+'"><a href="javascript:void(0);" onClick="javascript:RemovefromFilter(\'div_filter_cuisine_'+item_id+'\',\''+selectedFilter+'\');"><img src="{/literal}{$GLOBAL.tpl_url}{literal}/images/minus_icon.jpg" width="11" height="13" align="top" />&nbsp;'+item_name+' </a><input type="hidden" name="'+item_id+'" value="'+item_id+'"></div>';
	CurrentFilter		=	CurrentFilter+newFilter;
	document.getElementById('div_selected_filters').innerHTML	=	CurrentFilter;
	
	document.getElementById(div_name).style.display	=	'none';
}
function RemovefromFilter(div_name,filter_div)
{ 
	document.getElementById(div_name).style.display	=	'block';
	document.getElementById(filter_div).style.display	=	'none';
}

function showCuisineList()
{ 
	if(document.getElementById('div_cuisine_list').style.display == 'none')
	{
		document.getElementById('div_cuisine_list').style.display =	'block';
		document.getElementById('div_nhood_list').style.display   =	'none';
		document.getElementById('div_feature_list').style.display =	'none';
	}
	else
	{
			document.getElementById('div_cuisine_list').style.display =	'none';
	}

}

function showNhoodList()
{ 
	if(document.getElementById('div_nhood_list').style.display == 'none')
	{
		document.getElementById('div_nhood_list').style.display   =	'block';
		document.getElementById('div_feature_list').style.display =	'none';
		document.getElementById('div_cuisine_list').style.display =	'none';
	}
	else
	{
			document.getElementById('div_nhood_list').style.display =	'none';
	}

}

function showFeaturesList()
{ 
	if(document.getElementById('div_feature_list').style.display == 'none')
	{
		document.getElementById('div_feature_list').style.display =	'block';
		document.getElementById('div_nhood_list').style.display   =	'none';
		document.getElementById('div_cuisine_list').style.display =	'none';
	}
	else
	{
			document.getElementById('div_feature_list').style.display =	'none';
	}

}
function submitFilters()
{
	document.frm_filters.hid_search_fiters.value	=	"Y";	
	document.frm_filters.method	=	"post";
	document.frm_filters.submit();
}
function showFullLocations()
{
	document.getElementById('div_location_less').style.display =	'none';
	document.getElementById('div_location_full').style.display =	'block';
}
function showLessLocations()
{
	document.getElementById('div_location_full').style.display =	'none';
	document.getElementById('div_location_less').style.display =	'block';
}
</script>

{/literal}
<div class="top_banner">{$TOP_MAIN_BANNER}</div>
<div id="inner_mid" style="padding-bottom:0px;">
		<!-- START:Left Wrap-->
		<div id="left_wrap">
		
		
		
			<!-- START:Profile Wrap-->
			 <form  name="frm_filters" method="post" action="">
			<div class="box_wrap">
				<div class="box_wrap_top"><!-- --></div>
				<div class="box_wrap_inner" style="padding:0px 10px 0px 10px;">
				
					<div>
					  <span class="head_style01" style="float:inherit; padding-bottom:15px; display:block;">Filter</span>
					  <div id="div_selected_filter_box" style="display:none;">
						<table width="164" border="0" cellspacing="0" cellpadding="0">
						<tr>
						<td align="left" valign="top"><img src="{$GLOBAL.tpl_url}/images/boxtop_bg.jpg" width="160" height="6" /></td>
						</tr>
						<tr>
						<td align="left" valign="top">
						<div class="filter_top" id="div_selected_filters"> 	</div>	
						</td>
						</tr>
						<tr>
						<td align="left" valign="top"><img src="{$GLOBAL.tpl_url}/images/boxbtm_bg.jpg" width="160" height="6" /></td>
						</tr>
						<tr>
						<td align="left" valign="top">&nbsp;</td>
						</tr>
						</table>
					</div>
					 <div class="filterMenu_holder" >
					 {if $CUISINES.items|@count gt 0}
					  <div class="filterMenu" {if $CUISINES.items|@count gt 0} onClick="javascript:showCuisineList();" {/if}><a href="javascript:void(0);"  >Cusine</a></div>
					  <div  id="div_cuisine_list" style="display:none; position:absolute; ">
							  <table width="164" border="0" cellspacing="0" cellpadding="0">
								<tr>
								<td align="left" valign="top"><img src="{$GLOBAL.tpl_url}/images/boxtop_bg.jpg" width="160" height="6" /></td>
								</tr>
								<tr>
								<td align="left" valign="top">
								<div class="filter_top">
								{foreach from=$CUISINES.items item=cuisines}
								<div class="filter_link" id="div_filter_cuisine_{$cuisines.item_id}"><a  href="javascript:void(0);" class="normal_blicklink" onClick="javascript:AddtoFilter('{$cuisines.item_id}','{$cuisines.item_name}','div_filter_cuisine_{$cuisines.item_id}');"><img src="{$GLOBAL.tpl_url}/images/plus_icon.jpg" width="11" height="13" align="top" />&nbsp;{$cuisines.item_name}</a></div>
								{/foreach}						
								</div>	
								<div class="clear"><!-- --></div></td>
								</tr>
								<tr>
								<td align="left" valign="top"><img src="{$GLOBAL.tpl_url}/images/boxbtm_bg.jpg" width="160" height="6" /></td>
								</tr>
								<tr>
								<td align="left" valign="top">&nbsp;</td>
								</tr>
								</table>
						</div>
					  {/if}
					  {if $SEARCH_FEATURES.items|@count gt 0} 
					   <div class="filterMenu" {if $SEARCH_FEATURES.items|@count gt 0} onClick="javascript:showFeaturesList();"{/if}><a href="javascript:void(0);" >Features</a></div>
					     <div  id="div_feature_list" style="display:none; position:absolute; ">
							  <table width="164" border="0" cellspacing="0" cellpadding="0">
								<tr>
								<td align="left" valign="top"><img src="{$GLOBAL.tpl_url}/images/boxtop_bg.jpg" width="160" height="6" /></td>
								</tr>
								<tr>
								<td align="left" valign="top">
								<div class="filter_top">
								{foreach from=$SEARCH_FEATURES.items item=feature}
								<div class="filter_link" id="div_filter_cuisine_{$feature.item_id}"><a  href="javascript:void(0);" class="normal_blicklink" onClick="javascript:AddtoFilter('{$feature.item_id}','{$feature.item_name}','div_filter_cuisine_{$feature.item_id}');"><img src="{$GLOBAL.tpl_url}/images/plus_icon.jpg" width="11" height="13" align="top" />&nbsp;{$feature.item_name}</a></div>
								{/foreach}						
								</div>	
								<div class="clear"><!-- --></div></td>
								</tr>
								<tr>
								<td align="left" valign="top"><img src="{$GLOBAL.tpl_url}/images/boxbtm_bg.jpg" width="160" height="6" /></td>
								</tr>
								<tr>
								<td align="left" valign="top">&nbsp;</td>
								</tr>
								</table>
						</div>
						{/if}
						
						
					</div> 
					<!-- <div class="filterHead">Pricing</div>
					<div class="filterMenu_holder" style="padding:5px 0px;">
					  <table width="164" border="0" cellspacing="0" cellpadding="0">
                        <tr>
                          <td width="22"><input type="checkbox" name="chk_pricing_1" value="1" />
                          </td>
                          <td width="54"><img src="{$GLOBAL.tpl_url}/images/dolor.jpg" alt="" width="7" height="11" /></td>
                          <td width="22"><input type="checkbox" name="chk_pricing_4" value="4" /></td>
                          <td width="66"><img src="{$GLOBAL.tpl_url}/images/dolor.jpg" alt="" width="7" height="11" /><img src="{$GLOBAL.tpl_url}/images/dolor.jpg" alt="" width="7" height="11" /><img src="{$GLOBAL.tpl_url}/images/dolor.jpg" alt="" width="7" height="11" /><img src="{$GLOBAL.tpl_url}/images/dolor.jpg" alt="" width="7" height="11" /></td>
                        </tr>
                        <tr>
                          <td><input type="checkbox" name="chk_pricing_2" value="2" /></td>
                          <td><img src="{$GLOBAL.tpl_url}/images/dolor.jpg" alt="" width="7" height="11" /><img src="{$GLOBAL.tpl_url}/images/dolor.jpg" alt="" width="7" height="11" /></td>
                          <td><input type="checkbox" name="chk_pricing_5" value="5" /></td>
                          <td><img src="{$GLOBAL.tpl_url}/images/dolor.jpg" alt="" width="7" height="11" /><img src="{$GLOBAL.tpl_url}/images/dolor.jpg" alt="" width="7" height="11" /><img src="{$GLOBAL.tpl_url}/images/dolor.jpg" alt="" width="7" height="11" /><img src="{$GLOBAL.tpl_url}/images/dolor.jpg" alt="" width="7" height="11" /><img src="{$GLOBAL.tpl_url}/images/dolor.jpg" alt="" width="7" height="11" /></td>
                        </tr>
                        <tr>
                          <td><input type="checkbox" name="chk_pricing_3" value="3" /></td>
                          <td><img src="{$GLOBAL.tpl_url}/images/dolor.jpg" alt="" width="7" height="11" /><img src="{$GLOBAL.tpl_url}/images/dolor.jpg" alt="" width="7" height="11" /><img src="{$GLOBAL.tpl_url}/images/dolor.jpg" alt="" width="7" height="11" /></td>
                          <td>&nbsp;</td>
                          <td>&nbsp;</td>
                        </tr>
                      </table>
					</div>
					<div class="filterHead">Rating</div>
					<div class="filterMenu_holder" style="padding:5px 0px;">
					  <table width="164" border="0" cellspacing="0" cellpadding="0">
                        <tr>
                          <td width="22"><input type="checkbox" name="chk_rating_1" value="1" />
                          </td>
                          <td width="54"><img src="{$GLOBAL.tpl_url}/images/bowl.jpg" alt="" width="11" height="16" /></td>
                          <td width="22"><input type="checkbox" name="chk_rating_4" value="4" /></td>
                          <td width="66"><img src="{$GLOBAL.tpl_url}/images/bowl.jpg" alt="" width="11" height="16" /><img src="{$GLOBAL.tpl_url}/images/bowl.jpg" alt="" width="11" height="16" /><img src="{$GLOBAL.tpl_url}/images/bowl.jpg" alt="" width="11" height="16" /><img src="{$GLOBAL.tpl_url}/images/bowl.jpg" alt="" width="11" height="16" /></td>
                        </tr>
                        <tr>
                          <td><input type="checkbox" name="chk_rating_2" value="2" /></td>
                          <td><img src="{$GLOBAL.tpl_url}/images/bowl.jpg" alt="" width="11" height="16" /><img src="{$GLOBAL.tpl_url}/images/bowl.jpg" alt="" width="11" height="16" /></td>
                          <td><input type="checkbox" name="chk_rating_5" value="5" /></td>
                          <td><img src="{$GLOBAL.tpl_url}/images/bowl.jpg" alt="" width="11" height="16" /><img src="{$GLOBAL.tpl_url}/images/bowl.jpg" alt="" width="11" height="16" /><img src="{$GLOBAL.tpl_url}/images/bowl.jpg" alt="" width="11" height="16" /><img src="{$GLOBAL.tpl_url}/images/bowl.jpg" alt="" width="11" height="16" /><img src="{$GLOBAL.tpl_url}/images/bowl.jpg" alt="" width="11" height="16" /></td>
                        </tr>
                        <tr>
                          <td><input type="checkbox" name="chk_rating_3" value="3" /></td>
                          <td><img src="{$GLOBAL.tpl_url}/images/bowl.jpg" alt="" width="11" height="16" /><img src="{$GLOBAL.tpl_url}/images/bowl.jpg" alt="" width="11" height="16" /><img src="{$GLOBAL.tpl_url}/images/bowl.jpg" alt="" width="11" height="16" /></td>
                          <td>&nbsp;</td>
                          <td>&nbsp;</td>
                        </tr>
                      </table>
					</div> -->
					<div class="filterMenu_holder" style="padding:5px 0px;"><input type="hidden" name="hid_search_fiters" value="N">
					<input type="hidden" name="txt_city" value="{$smarty.request.txt_city}">
					<input type="hidden" name="txt_restaurant" value="{$smarty.request.txt_restaurant}">
					<a href="#" onClick="javascript:submitFilters();"><img src="{$GLOBAL.tpl_url}/images/btn_search.jpg" alt="" width="91" height="29" border="0" /></a></div>
			 		</div>
				
				
					
				</div>
				<div class="box_wrap_btm"><!-- --></div>
		  </div>
		 </form>
		  <div class="padding08"><!-- --></div>
			<!-- END:Profile Wrap-->
		
			<!-- START:Profile Wrap-->
			{if $RECENT_RESTAURANTS|@count ne 0}
			<div class="box_wrap">
			
				<div class="box_wrap_top"><!-- --></div>				
			  <div class="box_wrap_inner" style="padding:0px 0px 0px 10px;">
					
					<div class="">
							
					  <span class="head_style01 headstyle_padding">{$COM_VARIABLES.MOD_LABELS.LBL_HOME_RECENT}</span>
					  
					   <span class="padding02"><!-- --></span>
					   
					    {foreach from=$RECENT_RESTAURANTS item=recent}
					  <div class="raw01" style="width:170px;"><span class="raw01"><a  href="{makeLink mod=flyer pg=list}act=flyer_details&flyer_id={$recent.flyer_id}{/makeLink}" border="0">
						{if $recent.image ne ''} 
              	 <img src="{$GLOBAL.modbase_url}/flyer/images/widget/thumb/{$recent.image}" alt="{$recent.title}"  class="img_style"/>
				{else}
				 <img src="{$GLOBAL.modbase_url}/flyer/images/widget/thumb/default.jpg" alt="{$recent.title}"  class="img_style"/>
				{/if}</a></span>
					  <div class="raw01_content" style="width:110px;">
					    <table width="110" border="0" cellspacing="0" cellpadding="0">
					      <tr>
					        <td align="left" valign="top"><span class="normal_bold"><a  href="{makeLink mod=flyer pg=list}act=flyer_details&flyer_id={$recent.flyer_id}{/makeLink}" class="normal_bold">{$recent.title|truncate:25}</a></span><br />
				            {$recent.location_city}&nbsp; {$recent.location_zip} </td>
                          </tr>
					      
				        </table>
					  </div>
						      <div class="clear"></div>
						  
				  </div>
				   <span class="line_bg" style="padding-top:0px;"><!-- --></span>
				   {/foreach}
				   
								  
			  </div>
				
					
			  </div>
				<div class="box_wrap_btm"><!-- --></div>
			</div>
			{/if}
			<!-- END:Profile Wrap-->
			<div class="padding08"><!-- --></div>
			<!-- START:Profile Wrap-->
			{if $HOME_COUPONS|@count ne 0}
			<div class="box_wrap">
				<div class="box_wrap_top"><!-- --></div>
				<div class="box_wrap_inner" style="padding:0px 0px 0px 10px;">
					
					<div class="">
							
					  <span class="head_style01 headstyle_padding">Special Offers &amp; Coupons</span>
					  
					   <span class="padding02"><!-- --></span>
					   {foreach from=$HOME_COUPONS item=latest_coupons}
					   <div class="raw01" style="width:170px;"><span class="raw01">
					   <a  href="{makeLink mod=flyer pg=list}act=coupons&flyer_id={$latest_coupons.flyer_id}{/makeLink}" border="0">
						{if $latest_coupons.image ne ''} 
						 <img src="{$GLOBAL.modbase_url}/flyer/images/widget/thumb/{$latest_coupons.image}" alt="{$latest_coupons.title}"  class="img_style"/>
						{else}
						 <img src="{$GLOBAL.modbase_url}/flyer/images/widget/thumb/default.jpg" alt="{$latest_coupons.title}"  class="img_style"/>
						{/if}</a>
					   </span>
					  <div class="raw01_content" style="width:110px;">
					    <table width="110" border="0" cellspacing="0" cellpadding="0">
					      <tr>
					        <td align="left" valign="top"><span class="normal_bold"><a  href="{makeLink mod=flyer pg=list}act=coupons&flyer_id={$latest_coupons.flyer_id}{/makeLink}" border="0" class="normal_bold">{$latest_coupons.title|truncate:20}</a></span><br />
				           {$latest_coupons.description|truncate:50}</td>
                          </tr>
					      
				        </table>
					  </div>
						      <div class="clear"></div>
						  
				  </div>
				   <span class="line_bg" style="padding-top:0px;"><!-- --></span>
				   {/foreach}
				   
				  <div class="padding02" style="text-align:left" ><a href="#" class="normal_redlink_bold1">More Details</a></div>
				  
			  </div>
				
					
			  </div>
				<div class="box_wrap_btm"><!-- --></div>
			</div>
			{/if}
			<!-- END:Profile Wrap-->
			<div class="padding08"><!-- --></div>
			<!-- START:Profile Wrap-->
			<div class="box_wrap">
				<div class="box_wrap_top"><!-- --></div>
				<div class="box_wrap_inner" style="padding:0px;">
					
					
					
					<div style="text-align:center;"> {$GADD3}<!-- <img src="{$GLOBAL.tpl_url}/images/ad_banner.jpg" alt="" width="160" height="600" /> --></div>
					
				
					
				</div>
				<div class="box_wrap_btm"><!-- --></div>
			</div>
			<!-- END:Profile Wrap-->
			<div class="padding08"><!-- --></div>
			
			
		</div>
		<!-- END:Left Wrap-->
		
		<!-- START:Right Wrap-->
		<div id="right_wrap">
			<div class="ad_wrap01">{$GADD}</div>
			
			<div class="padding08">
				<div style="width:453px; float:left;">
				 
				 <!--CITIES -->
				 {if $SHOW_LOCATIONS eq 'Y'}
					 {if $LOCATIONS_COUNT gt 0 }
						<div class="list_wrap" style="margin-bottom:10px;" id="div_location_less">
						<div class="list_wrap_top"><!-- --></div>
						   <div class="list_wrap_inner">
						   <table width="423" border="0" cellspacing="0" cellpadding="0">
						  <tr>
							<td height="30" colspan="3" class="title01">{$LOCATIONS_LABEL}</td>
							</tr>
						  <tr>
						   {assign var="col1" value="1"} 
						 {foreach from=$LOCATIONS_FULL item=loc_full key=key } 
						 {if $key lt 12 }
							<td width="141" align="left" valign="top" class="cities"><a href="{makeLink mod=flyer pg=list}act=search&hid_advanced_search=Y&{$LOCATIONS_VARIABLE}={$loc_full.location}{/makeLink}">{$loc_full.location|lower|capitalize} </a></td>
							{if $col1%3 eq 0}	
							</tr>
						  {/if}
						 {assign var="col1" value="`$col1+1`"} 
						 {/if}
						 {/foreach}
						  <tr>
							<td height="25" colspan="3" align="right" valign="bottom">
							{if $LOCATIONS_COUNT gt 12 }
							<a href="#"  onClick="javascript:showFullLocations();" class="normal_redlink_bold1">More {$LOCATIONS_LABEL}</a>
							{/if}
							</td>
							</tr>
						</table>
					  </div>
					  <div class="list_wrap_bottom"><!-- --></div>
		      	  </div>
				  <div class="list_wrap" style="margin-bottom:10px; display:none;" id="div_location_full">
						<div class="list_wrap_top"><!-- --></div>
						   <div class="list_wrap_inner">
						   <table width="423" border="0" cellspacing="0" cellpadding="0">
						  <tr>
							<td height="30" colspan="3" class="title01">{$LOCATIONS_LABEL}</td>
							</tr>
						  <tr>
						   {assign var="col1" value="1"} 
						 {foreach from=$LOCATIONS_FULL item=loc_full} 
							<td width="141" align="left" valign="top" class="cities"><a href="{makeLink mod=flyer pg=list}act=search&hid_advanced_search=Y&{$LOCATIONS_VARIABLE}={$loc_full.location}{/makeLink}">{$loc_full.location|lower|capitalize} </a></td>
							{if $col1%3 eq 0}	
							</tr>
						  {/if}
						 {assign var="col1" value="`$col1+1`"} 
						 {/foreach}
						  <tr>
							<td height="25" colspan="3" align="right" valign="bottom"><a href="#"  onClick="javascript:showLessLocations();" class="normal_redlink_bold1">{$LOCATIONS_LABEL}</a></td>
							</tr>
						</table>
					  </div>
					  <div class="list_wrap_bottom"><!-- --></div>
		      	  </div>
				  {/if}
				  {/if}
				<!--CITIES END -->
				 
				<div class="list_wrap">
					<div class="list_wrap_top"><!-- --></div>
					   <div class="list_wrap_inner">
						 <div class="page_nav">
								<a href="{$GLOBAL.site_url}">Home</a> <span class="nav_img"></span> <a href="{makeLink mod=flyer pg=list}act=allcity{/makeLink}">Restaurant</a> 
								  {if $SEARCHLOCPATH.location_state ne ''}<span class="nav_img"></span> <a href="{makeLink mod=flyer pg=list}act=search&hid_advanced_search=Y&location_state={$SEARCHLOCPATH.location_state}{/makeLink}">{$SEARCHLOCPATH.location_state|lower|capitalize}</a>
								 	{if $SEARCHLOCPATH.location_county ne ''}<span class="nav_img"></span> <a href="{makeLink mod=flyer pg=list}act=search&hid_advanced_search=Y&location_county={$SEARCHLOCPATH.location_county}{/makeLink}">{$SEARCHLOCPATH.location_county|lower|capitalize}</a>
								 		{if $SEARCHLOCPATH.location_city ne ''}<span class="nav_img"></span> <a href="{makeLink mod=flyer pg=list}act=search&hid_advanced_search=Y&location_city={$SEARCHLOCPATH.location_city}{/makeLink}">{$SEARCHLOCPATH.location_city|lower|capitalize}</a>	{/if}
								  	{/if}
								  {/if}
								<div class="clear"></div>
							 {if $smarty.request.location_city ne ''}  <span class="head_style01">Restaurants in {$smarty.request.location_city|lower|capitalize}</span> {/if}
							   
							   <span class="head_style04 padding_10" style="text-align:right; float:right;">Results {$RESULT_START}-{$LIMIT} of {$RESTAURANT_COUNT} </span>
						</div><br clear="all" />
						
							<div style="padding-top:15px;">
								<div>
								  <table width="423" border="0" cellspacing="0" cellpadding="0">
									  <tr>
										<td width="9" align="left" valign="top"><img src="{$GLOBAL.tpl_url}/images/box_left_img.jpg" alt="" width="9" height="36" /></td>
										<td width="405" align="left" valign="top" style="background:url({$GLOBAL.tpl_url}/images/box_bg.jpg) repeat-x left top;"><table width="405" border="0" cellspacing="0" cellpadding="0">
										  <tr class="text_small_bold">
											<!-- <td width="91" height="36" align="center" valign="middle">Restaurant</td> --> 
											<td width="91" height="36" align="center" valign="middle" class="text_small_bold">{makeLink mod=flyer pg=list orderBy="a.title" display="Restaurant"}act=search&hid_advanced_search={$smarty.request.hid_advanced_search}&filter_aminities={$smarty.request.filter_aminities}&filter_pricing={$smarty.request.filter_pricing}&filter_rating={$smarty.request.filter_rating}&cuisine_id={$smarty.request.cuisine_id}&txt_restaurant={$smarty.request.txt_restaurant}&txt_city={$smarty.request.txt_city}&location_state={$smarty.request.location_state}&location_county={$smarty.request.location_county}&location_city={$smarty.request.location_city}&location_neighborhood={$smarty.request.location_neighborhood}&adsearch_cuisine={$smarty.request.adsearch_cuisine}&adsearch_feature={$smarty.request.adsearch_feature}&adsearch_meal={$smarty.request.adsearch_meal}&hid_search_fiters=Y&pageNo={$PAGENO}&limit={$LIMIT} {/makeLink}</td>
											<td width="75" align="center" valign="middle" >Cuisine </td>
											<td width="86" align="center" valign="middle">{makeLink mod=flyer pg=list orderBy="d.location_neighborhood" display="Neighborhood"}act=search&hid_advanced_search={$smarty.request.hid_advanced_search}&filter_aminities={$smarty.request.filter_aminities}&filter_pricing={$smarty.request.filter_pricing}&filter_rating={$smarty.request.filter_rating}&cuisine_id={$smarty.request.cuisine_id}&txt_restaurant={$smarty.request.txt_restaurant}&txt_city={$smarty.request.txt_city}&location_state={$smarty.request.location_state}&location_county={$smarty.request.location_county}&location_city={$smarty.request.location_city}&location_neighborhood={$smarty.request.location_neighborhood}&adsearch_cuisine={$smarty.request.adsearch_cuisine}&adsearch_feature={$smarty.request.adsearch_feature}&adsearch_meal={$smarty.request.adsearch_meal}&hid_search_fiters=Y&pageNo={$PAGENO}&limit={$LIMIT} {/makeLink}</td>
											<td width="75" align="center" valign="middle" class="text_small_bold"> {makeLink mod=flyer pg=list orderBy="a.price" display="Pricing"}act=search&hid_advanced_search={$smarty.request.hid_advanced_search}&filter_aminities={$smarty.request.filter_aminities}&filter_pricing={$smarty.request.filter_pricing}&filter_rating={$smarty.request.filter_rating}&cuisine_id={$smarty.request.cuisine_id}&txt_restaurant={$smarty.request.txt_restaurant}&txt_city={$smarty.request.txt_city}&location_state={$smarty.request.location_state}&location_county={$smarty.request.location_county}&location_city={$smarty.request.location_city}&location_neighborhood={$smarty.request.location_neighborhood}&adsearch_cuisine={$smarty.request.adsearch_cuisine}&adsearch_feature={$smarty.request.adsearch_feature}&adsearch_meal={$smarty.request.adsearch_meal}&hid_search_fiters=Y&pageNo={$PAGENO}&limit={$LIMIT} {/makeLink}</td>
											<td width="78" align="center" valign="middle" class="text_small_bold">{makeLink mod=flyer pg=list orderBy="a.rate" display="Rating" }act=search&hid_advanced_search={$smarty.request.hid_advanced_search}&filter_aminities={$smarty.request.filter_aminities}&filter_pricing={$smarty.request.filter_pricing}&filter_rating={$smarty.request.filter_rating}&cuisine_id={$smarty.request.cuisine_id}&txt_restaurant={$smarty.request.txt_restaurant}&txt_city={$smarty.request.txt_city}&location_state={$smarty.request.location_state}&location_county={$smarty.request.location_county}&location_city={$smarty.request.location_city}&location_neighborhood={$smarty.request.location_neighborhood}&adsearch_cuisine={$smarty.request.adsearch_cuisine}&adsearch_feature={$smarty.request.adsearch_feature}&adsearch_meal={$smarty.request.adsearch_meal}&hid_search_fiters=Y&pageNo={$PAGENO}&limit={$LIMIT} {/makeLink}</td>
										  </tr>
										</table></td>
										<td width="9" align="right" valign="top"><img src="{$GLOBAL.tpl_url}/images/box_rht_img.jpg" alt="" width="9" height="36" /></td>
									  </tr>
								  </table>
								</div>
								
								{foreach from=$RESTAURANT_LIST item=restaurants}
								{if  $restaurants->free_listing ne 'Y'}
							<div class="res_listing_outer">
							  <div class="{cycle name=bg values="res_listing1,res_listing"}">
							    
								<table width="405" border="0" align="center" cellpadding="0" cellspacing="0">
                                  <tr>
                                    <td width="93" rowspan="2" align="center" valign="top">
									<a  href="{makeLink mod=flyer pg=list}act=flyer_details&flyer_id={$restaurants->flyer_id}{/makeLink}" border="0">
									{if $restaurants->package_id eq '0'} 
									<img src="{$GLOBAL.tpl_url}/images/restaurant_thumb.jpg" alt="{$restaurants->title}"  class="img_style"/>
									{else}
									
									{if $restaurants->image ne ''} 
									<img src="{$GLOBAL.modbase_url}/flyer/images/medium_gallary/thumb/{$restaurants->image}" alt="{$restaurants->title|truncate:50}"  class="img_style"/>
									{else}
									<img src="{$GLOBAL.modbase_url}/flyer/images/widget/thumb/default.jpg" alt="{$restaurants->title}"  class="img_style"/>
									{/if}
									{/if}
									</a>
									<!-- <img src="images/img_02.jpg" alt="" width="89" height="87" class="img_border"/> --></td>
                                    <td width="71" height="40" align="center" valign="top">
									<!-- <table width="70" border="0" cellspacing="0" cellpadding="2">
										{foreach from=$restaurants->cuisines item=cuisines key=key}
                                        <tr>
                                          <td align="center" valign="top">{if $key lt 3} {$cuisines} {/if}</td>
                                        </tr>
										{/foreach}
                                       
                                    </table> -->
									{$restaurants->cuisine}
									
									</td>
                                    <td width="85" align="center" valign="top">{$restaurants->location_neighborhood}</td>
                                    <td width="77" align="center" valign="top" >&nbsp;&nbsp;{if $restaurants->price ne ''}<img src="{$GLOBAL.tpl_url}/images/price{$restaurants->price}.gif"  />{else}<img src="{$GLOBAL.tpl_url}/images/price0.gif"  /> {/if}</td>
                                    <td width="79" rowspan="2" align="center" valign="top"><table width="68" border="0" cellspacing="0" cellpadding="0">
                                        <tr>
                                          <td align="left" valign="top">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;{if  $restaurants->rate ne ''}<img src="{$GLOBAL.tpl_url}/images/rate{$restaurants->rate}.gif"  />{else}<img src="{$GLOBAL.tpl_url}/images/rate0.gif"  /> {/if}</td>
                                        </tr>
                                        <tr>
                                          <td height="65" align="center" valign="bottom">{if $restaurants->package_id ne '0'}<a href="#"><img src="{$GLOBAL.tpl_url}/images/call_icon.gif" alt="" width="68" height="48" border="0" /></a>{/if}</td>
                                        </tr>
                                    </table></td>
                                  </tr>
                                  <tr>
                                    <td height="25" colspan="3" align="left" valign="bottom" class="head01" style="padding-left:15px;"><a class="head01" href="{makeLink mod=flyer pg=list}act=flyer_details&flyer_id={$restaurants->flyer_id}{/makeLink}" border="0">{$restaurants->title} </a></td>
                                  </tr>
                                </table>
							 	
								
							  </div>
								
								<div class="{cycle name=free values="res_wrap01,res_wrap02"}">
									{if $restaurants->package_id eq '0'} 
									<table width="100%" border="0" cellspacing="0" cellpadding="0">
									  <tr>
										<td width="42%">
										<div class="page_nav01"><span ></span><!-- <a href="{makeLink mod=flyer pg=list}act=flyer_details&flyer_id={$restaurants->flyer_id}&tab=1#tabs{/makeLink}">Video</a> --> <span ></span> <!-- <a href="{makeLink mod=flyer pg=list}act=flyer_details&flyer_id={$restaurants->flyer_id}&tab=2#tabs{/makeLink}">Pictures</a> --><span ></span> <!-- <a href="{makeLink mod=flyer pg=list}act=flyer_details&flyer_id={$restaurants->flyer_id}&tab=3#tabs{/makeLink}">Coupons</a> --><br clear="all" /></div>
										</td>
										<td width="35%" ></td>
										<td width="23%"><a href="#" class="redButton" onClick="popUpHtmlBlockMap('{$restaurants->lat}','{$restaurants->lon}', '<strong>{$restaurants->title}<br>{$restaurants->location_city},{$restaurants->location_state},{$restaurants->location_country}</strong>'); return false;"><span>Show on Map</span></a></td>
									  </tr>
									</table>
									{else}
									
									<table width="100%" border="0" cellspacing="0" cellpadding="0">
									  <tr>
										<td width="42%">
										<div class="page_nav01"><span class="nav_img01"></span><a href="{makeLink mod=flyer pg=list}act=flyer_details&flyer_id={$restaurants->flyer_id}&tab=1#tabs{/makeLink}">Video</a> <span class="nav_img"></span> <a href="{makeLink mod=flyer pg=list}act=flyer_details&flyer_id={$restaurants->flyer_id}&tab=2#tabs{/makeLink}">Pictures</a><span class="nav_img"></span> <a href="{makeLink mod=flyer pg=list}act=flyer_details&flyer_id={$restaurants->flyer_id}&tab=3#tabs{/makeLink}">Coupons</a><br clear="all" /></div>
										</td>
										<td width="35%" class="reservation_icon"><a href="#">Make Reservation</a> </td>
										<td width="23%"><a href="#" class="redButton" onClick="popUpHtmlBlockMap('{$restaurants->lat}','{$restaurants->lon}', '<strong>{$restaurants->title}<br>{$restaurants->location_city},{$restaurants->location_state},{$restaurants->location_country}</strong>'); return false;"><span>Show on Map</span></a></td>
									  </tr>
									</table>
									{/if}

								</div>
								
							  </div>
							  {else}
							  <div class="res_listing_outer">
								<div class="{cycle name=bg values="res_listing1,res_listing"}">
								
							    <table width="405" border="0" align="center" cellpadding="0" cellspacing="0">
                                  <tr>
                                    <td width="93" rowspan="2" align="center" valign="top"><a  href="{makeLink mod=flyer pg=list}act=flyer_details&flyer_id={$restaurants->flyer_id}{/makeLink}" border="0"><img src="{$GLOBAL.tpl_url}/images/img_no.gif" alt="" width="89" height="50" class="img_border"/></a></td>
                                    <td width="71" height="29" align="center" valign="top"><table width="70" border="0" cellspacing="0" cellpadding="2">
                                       {foreach from=$restaurants->cuisines item=cuisines key=key}
                                        <tr>
                                          <td align="center" valign="top">{if $key lt 1} {$cuisines} {/if}</td>
                                        </tr>
										{/foreach}
                                        
                                    </table></td>
                                    <td width="85" align="center" valign="top">{$restaurants->location_neighborhood}</td>
                                    <td width="59" align="center" valign="top">&nbsp;&nbsp;{if $restaurants->price ne ''}<img src="{$GLOBAL.tpl_url}/images/price{$restaurants->price}.gif"  />{else}<img src="{$GLOBAL.tpl_url}/images/price0.gif"  /> {/if}</td>
                                    <td width="97" align="center" valign="top"><table width="68" border="0" cellspacing="0" cellpadding="0">
                                        <tr>
                                          <td align="left" valign="top">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;{if  $restaurants->rate ne ''}<img src="{$GLOBAL.tpl_url}/images/rate{$restaurants->rate}.gif"  />{else}<img src="{$GLOBAL.tpl_url}/images/rate0.gif"  /> {/if}</td>
                                        </tr>
                                        
                                    </table></td>
                                  </tr>
                                  
                                  <tr>
                                    <td colspan="3" align="left" valign="middle" class="head01" style="padding-left:15px;"><a class="head01" href="{makeLink mod=flyer pg=list}act=flyer_details&flyer_id={$restaurants->flyer_id}{/makeLink}" border="0">{$restaurants->title|truncate:50}</a></td>
                                    <td align="center" valign="top"><a href="#" onClick="popUpHtmlBlockMap('{$restaurants->lat}','{$restaurants->lon}', '<strong>{$restaurants->title}<br>{$restaurants->location_city},{$restaurants->location_state},{$restaurants->location_country}</strong>'); return false;" class="redButton"><span>Show on Map</span></a></td>
                                  </tr>
                                </table>
								
								
								</div>
								
								
								
								</div>
							  
							  {/if}
								{/foreach}
								

								
								<div style="height:30px;">  
								<span class="paging_nav"> 	
								{$RESTAURANT_NUMPAD}
								<!-- <a href="#">« Previous</a>  <a href="#">1</a>  <a href="#">2</a>  <a href="#">3</a>
								 <a href="#">4</a>  <a href="#">5</a>  <a href="#">6</a>  <a href="#">7 </a> <a href="#">8</a>  <a href="#">9</a>  <a href="#">10 </a>  <a href="#">Next »</a> --></span>
								<span class="head_style04 padding_10" style="text-align:right; float:right;">Results {$RESULT_START}-{$LIMIT} of {$RESTAURANT_COUNT} </span>
								</div>
								
							  
					     </div>
							
				  </div>
						
						
			      </div>
					<div class="list_wrap_bottom"><!-- --></div>
					
			  </div>
				
				<div class="listright_wrap" style="height:auto; width:287px;">
				
					<div>
						<div class="listright_wrap_top"><!-- --></div>
								<div id="div_floatting_postion" class="listright_wrap_inner" style="width:287px; text-align:center; padding:0px; height:1270px;">
									<!-- <div><img src="{$GLOBAL.tpl_url}/images/map_img2.jpg" width="274" height="269" /></div> -->
									<div  id="floatting_div" style="width:274px;font-size:11px;margin:0px 4px 5px 5px;padding:0px; position:relative; border:1px solid #FF0000; vertical-align:middle;"   >
									&nbsp;<div id="tooltip"></div>
								  <div id="mapContainer" class="orange4"  style="padding-left:10px;"><img src="{$GLOBAL.tpl_url}/images/loadingB.gif"></div>
								 {$My_Map}</div>
									<div style="padding:10px 0px 10px 0px;">{$BANNER_ADS4}<!-- <img src="{$GLOBAL.tpl_url}/images/ad_banner11.jpg" width="250" height="250" /> --></div>
									
									<div>{$BANNER_ADS5}<!-- <img src="{$GLOBAL.tpl_url}/images/banner2.jpg" width="254" height="260" /> --></div>
								</div>
						<div class="listright_wrap_bottom"><!-- --></div>
					</div>
					<div class="clear"></div>
				</div>
				
				<div class="clear"></div>
			</div>
			
		
		</div>
		<!-- END:Right Wrap-->
		
		
		<br clear="all" />
	</div>
	
{literal}
<script type="text/javascript">
var ns = (navigator.appName.indexOf("Netscape") != -1);
var d = document;
function JSFX_FloatDiv(id, sx, sy)
{
	var el=d.getElementById?d.getElementById(id):d.all?d.all[id]:d.layers[id];
	var px = document.layers ? "" : "px";
	window[id + "_obj"] = el;
	if(d.layers)el.style=el;
	el.cx = el.sx = sx;el.cy = el.sy = sy;
	el.sP=function(x,y){this.style.left=x+px;this.style.top=y+px;};

	el.floatIt=function()
	{
		var pX, pY;
		pX = (this.sx >= 0) ? 0 : ns ? innerWidth : 
		document.documentElement && document.documentElement.clientWidth ? 
		document.documentElement.clientWidth : document.body.clientWidth;
		pY = ns ? pageYOffset : document.documentElement && document.documentElement.scrollTop ? 
		document.documentElement.scrollTop : document.body.scrollTop;
		if(this.sy<0) 
		pY += ns ? innerHeight : document.documentElement && document.documentElement.clientHeight ? 
		document.documentElement.clientHeight : document.body.clientHeight;
		this.cx += (pX + this.sx - this.cx)/2;this.cy += (pY + this.sy - this.cy)/2;
		this.sP(this.cx, this.cy);
		setTimeout(this.id + "_obj.floatIt()", 40);
	}
	return el;
}
//JSFX_FloatDiv("floatting_div", 11 + (document.all ? 2 : 0),170).floatIt();
//alert(document.getElementById('div_floatting_postion').style.left);
JSFX_FloatDiv("floatting_div",0,0).floatIt();
</script>
{/literal}