<div class="profile_wrap02">
					<div class="profile_wrap_top02"><!-- --></div>
					
				  <div class="profile_wrap_inner02">
					 <div class="profile02_container">
					   <div  class="tab01">
					<ul>
					
					<li><a href="{makeLink mod=member pg=account}act=myaccount{/makeLink}"><span>{$MOD_VARIABLES.MOD_BLOCKS.HT_PROFILE}</span></a></li>
					<li><a href="#"><span>{$MOD_VARIABLES.MOD_BLOCKS.HT_FAVOURITES}</span></a></li>
					<li><a href="#"><span>{$MOD_VARIABLES.MOD_BLOCKS.HT_REVIEWS}</span></a></li>
					<li><a href="{makeLink mod=member pg=account}act=myaccount&photo_album=&type=photo{/makeLink}"><span>{$MOD_VARIABLES.MOD_BLOCKS.HT_PHOTOS}</span></a></li>
					<li><a href="#"><span>{$MOD_VARIABLES.MOD_BLOCKS.HT_BLOGS}</span></a></li>
					<li><a href="#"><span>{$MOD_VARIABLES.MOD_BLOCKS.HT_MY_RESTAURANTEUR}</span></a></li>
					<li><a href="#"><span>{$MOD_VARIABLES.MOD_BLOCKS.HT_MY_RESTAURANT}</span></a></li>
					<li><a href="#"><span>{$MOD_VARIABLES.MOD_BLOCKS.HT_MY_REPORT}</span></a></li>
					
					</ul>
					<div class="clear"></div>
					   </div>
					   <div style="border:1px solid #CCCCCC; border-top:0px; padding-left:10px;">
							 <table width="708" border="0" cellspacing="0" cellpadding="0">
							  <tr>
								<td height="23" align="right"><!-- <a href="{makeLink mod=flyer pg=list}act=add_step1{/makeLink}" class="redButton"><span>Add Restaurant</span></a> --></td>

							  </tr>
							  
							  
							  {if count(REST_LIST) gt 0}
							  {foreach from=$REST_LIST item=rest_item}
							  <tr>
								<td><table width="700" border="0" cellspacing="0" cellpadding="0">
                                  <tr>
                                    <td width="110" align="left" valign="top"><a href="{makeLink mod=member pg=account}act=profile_view&profile_id={$rest_item.id}{/makeLink}"><img src="{if $rest_item.image=='Y'} {$GLOBAL.site_url}/modules/member/images/userpics/thumb/{$rest_item.friend_id}.jpg?{$smarty.now} {else}{$GLOBAL.modbase_url}/member/images/default.jpg{/if}"  alt="{$rest_item.username}"  /></a></td>
                                    <td width="590" align="left" valign="top"><table width="100%" border="0" cellspacing="0" cellpadding="0">
                                        <tr>
                                          <td width="80%" height="22" class="head01">{$rest_item.first_name} {$rest_item.last_name}</td>

                                          <td width="20%" class="normal_bold">&nbsp;</td>
                                        </tr>
                                        <tr>
                                          <td>{$rest_item.email}, {$rest_item.telephone} <br />
                                            {$rest_item.address1} <br />
                                          </td>
                                          <td>&nbsp;</td>
                                        </tr>

                                    </table></td>
                                  </tr>
                                </table></td>
							  </tr>							  
							  <tr>
								<td class="sep_dotline"></td>
							  </tr>
							  {/foreach}
							  {/if}
							 
							 <tr>
							   <td >{$NUMPAD}</td>
						       </tr>
							   
							  <tr>
							   <td class="sep_dotline"></td>
						       </tr>
							   
							   
							   
							  
							  
					     </table>

				 	   </div>
				    </div>
				  </div>
					<div class="profile_wrap_bottom02"><!-- --></div>
					
				</div>