 <script language="javascript" type="text/javascript" src="{$smarty.const.SITE_URL}/includes/ajax/ajax.js"></script>
 <script language="javascript">
 {literal}
function getRestaurant(txt_phone_no,restauranteur_id)
{ 
	var req1 = newXMLHttpRequest();
	req1.onreadystatechange = getReadyStateHandler(req1, serverReseUsr);
	str="txt_phone_no="+txt_phone_no+"&restauranteur_id="+restauranteur_id;
	{/literal}
	req1.open("POST", "{makeLink mod=flyer pg=show_restaurant}act=selection{/makeLink}&"+Math.random());
	{literal}
	req1.setRequestHeader("Content-Type","application/x-www-form-urlencoded; charset=UTF-8");
	req1.send(str);
}
function serverReseUsr(_var) 
{ 
			
		document.getElementById('div_restaurant_display').innerHTML=_var;
		
}


function clearrestaurant()
{
	if(document.getElementById('txt_phone_no').value == 'Restaurant Phone')
	{
		
		document.getElementById('txt_phone_no').value =	'';
	}
}

{/literal}
</script>
<div id="right_wrap">
			<div class="ad_wrap01"><!-- <img src="{$GLOBAL.tpl_url}/images/adimg.jpg" alt="" width="728" height="90" /> -->{$GADD}</div>
			
			<div class="padding08">
				<div style="width:750px; float:left; ">
				<div class="profile_wrap02">
					<div class="profile_wrap_top02"><!-- --></div>
					
				  <div class="profile_wrap_inner02">
					 <div class="profile02_container">
					<div class="page_nav" style="height:34px;">
						<a href="{makeLink mod=member pg=account}act=myaccount{/makeLink}">Home</a> <span class="nav_img"></span> <a href="#">Restauranteurs</a><a href="#"></a>
						<div class="clear"></div>
					   </div>
						<div class="head04">Select a Restaurant</div>
					    <div class="padding07">
						 <div class="padding07">
						   <div class="form_row_field">
					       <div class="message_holder" style="display:;"></div>
						    <form name="frm_usr" method="post" action="">
						   <table width="100%" border="0" cellspacing="0" cellpadding="0">
                             <tr>
                               <td width="26%">Enter the Phone Number: </td>
                               <td width="74%" align="left" valign="middle"><span class="field_wrap_form">
                                 <input name="txt_phone_no" id="txt_phone_no" type="text" class="text_field_form" style="width:200px;" value="Restaurant Phone" onBlur="javascript:clearrestaurant();" onFocus="javascript:clearrestaurant();" />
								 </span>
							   <a href="javascript:void(0);" class="redButton" onClick="javascipt:getRestaurant(document.frm_usr.txt_phone_no.value,'{$smarty.request.restauranteur_id}');"><span>Next</span></a>
							   </td>
                             </tr>
                           </table>
						   </form>
					     </div>
						 <div id="div_restaurant_display">
						     <table width="100%" border="0" cellspacing="0" cellpadding="0">
							 {foreach from=$RESTAURNTS item=restaurant}
                               <tr>
                                 <td align="left" valign="top"><table width="700" border="0" cellspacing="0" cellpadding="0">
                                     <tr>
                                       <td width="110" align="left" valign="top"><img src="{$GLOBAL.tpl_url}/images/restaurant_thumb.jpg" alt="" width="91" height="52" /></td>
                                       <td width="590" align="left" valign="top"><table width="100%" border="0" cellspacing="0" cellpadding="0">
                                           <tr>
                                             <td width="80%" height="22" class="head01">{$restaurant.title}</td>
                                             <td width="20%" class="normal_bold">&nbsp;</td>
                                           </tr>
                                           <tr>
                                             <td>{$restaurant.description|truncate:165}                               </td>
                                             <td><a href="{makeLink mod=flyer pg=list}act=select_pack&restauranteur_id={$smarty.request.restauranteur_id}&flyer_id={$restaurant.flyer_id}{/makeLink}" class="selectBtn"><span>Select</span></a></td>
                                           </tr>
                                       </table></td>
                                     </tr>
                                 </table></td>
                               </tr>
                               <tr>
                                 <td class="sep_dotline"></td>
                               </tr>
							   {/foreach}
							   
                              
                               <tr>
                                 <td align="left" valign="top">&nbsp;</td>
                               </tr>
                             </table>
						   </div> 
						  
						</div>
						</div>
					    <div class="clear"></div>
				    </div>
				  </div>
				  
					<div class="profile_wrap_bottom02"><!-- --></div>
					
				</div>	
				<div class="clear"></div>
				<div class="padding08"><!-- --></div>			
				</div>
				<div class="clear"></div>
			</div>
			
		
		</div>