 <script language="javascript" type="text/javascript" src="{$smarty.const.SITE_URL}/includes/ajax/ajax.js"></script>
 <script language="javascript">
 {literal}
function getusers(search_tag)
{ 
	var req1 = newXMLHttpRequest();
	req1.onreadystatechange = getReadyStateHandler(req1, serverReseUsr);
	str="search_tag="+search_tag;
	{/literal}
	req1.open("POST", "{makeLink mod=flyer pg=show_user}act=selection{/makeLink}&"+Math.random());
	{literal}
	req1.setRequestHeader("Content-Type","application/x-www-form-urlencoded; charset=UTF-8");
	req1.send(str);
}
function serverReseUsr(_var) 
{ 
		//alert(_var)
		
		document.getElementById('div_usr_display').innerHTML=_var;
}

function clearrestauranteur()
{
	if(document.getElementById('txt_ajax_user').value == 'Restauranteur Name')
	{
		
		document.getElementById('txt_ajax_user').value =	'';
	}
}

{/literal}
</script>
<div id="right_wrap">
			<div class="ad_wrap01"><!-- <img src="{$GLOBAL.tpl_url}/images/adimg.jpg" alt="" width="728" height="90" /> -->{$GADD}</div>
			
			<div class="padding08">
				<div style="width:750px; float:left; ">
				<div class="profile_wrap02">
					<div class="profile_wrap_top02"><!-- --></div>
					
				  <div class="profile_wrap_inner02">
					 <div class="profile02_container">
					<div class="page_nav" style="height:34px;">
						<a href="#">Home</a> <span class="nav_img"></span> <a href="#">Restauranteurs</a><a href="#"></a>
						<div class="clear"></div>
					   </div>
						<div class="head04">{$MOD_VARIABLES.MOD_LABELS.LBL_SELECT_RESTAURANT_USER}</div>
					    <div class="padding07">
					     <div class="form_row_field">
					       <div class="message_holder" style="display:;"></div>
						   <form name="frm_usr" method="post" action="">
						   <table width="100%" border="0" cellspacing="0" cellpadding="0">
                             <tr>
                               <td width="30%">{$MOD_VARIABLES.MOD_LABELS.LBL_ENTER_USER_NAME}</td>
                               <td width="70%" align="left" valign="middle"><span class="field_wrap_form">
                                 <input name="txt_ajax_user" id="txt_ajax_user" type="text" class="text_field_form" style="width:200px;" value="Restauranteur Name" onBlur="javascript:clearrestauranteur();" onFocus="javascript:clearrestauranteur();"  />
					
                               </span>  <a href="javascript:void(0);" class="redButton" onClick="javascript:getusers(document.frm_usr.txt_ajax_user.value);"><span>Next</span></a></td>
                             </tr>
                           </table>
						   </form>
					     </div>
						
						 <div class="padding01" id="div_usr_display">
						
						 </div>   <!--
						 <div class="head04">Select a Restaurant</div>
						 
						 <div class="padding07">
						   <div class="form_row_field">
					       <div class="message_holder" style="display:;"></div>
						   <table width="100%" border="0" cellspacing="0" cellpadding="0">
                             <tr>
                               <td width="26%">Enter the Phone Number: </td>
                               <td width="74%" align="left" valign="middle"><span class="field_wrap_form">
                                 <input name="text2" type="text" class="text_field_form" style="width:200px;" value="Restaurant Phone" />
                               </span></td>
                             </tr>
                           </table>
					     </div>
						     <table width="100%" border="0" cellspacing="0" cellpadding="0">
                               <tr>
                                 <td align="left" valign="top"><table width="700" border="0" cellspacing="0" cellpadding="0">
                                     <tr>
                                       <td width="110" align="left" valign="top"><img src="{$GLOBAL.tpl_url}/images/restaurant_thumb.jpg" alt="" width="91" height="52" /></td>
                                       <td width="590" align="left" valign="top"><table width="100%" border="0" cellspacing="0" cellpadding="0">
                                           <tr>
                                             <td width="80%" height="22" class="head01">Lorem ipsum dolor sit amet, consectetur </td>
                                             <td width="20%" class="normal_bold">&nbsp;</td>
                                           </tr>
                                           <tr>
                                             <td>Lorem ipsum dolor sit amet, consectetur <br />
                                               dolor sit amet, consectetur  <br />                                            </td>
                                             <td><a href="#" class="selectBtn"><span>Select</span></a></td>
                                           </tr>
                                       </table></td>
                                     </tr>
                                 </table></td>
                               </tr>
                               <tr>
                                 <td class="sep_dotline"></td>
                               </tr>
                               <tr>
                                 <td align="left" valign="top"><table width="700" border="0" cellspacing="0" cellpadding="0">
                                   <tr>
                                     <td width="110" align="left" valign="top"><img src="{$GLOBAL.tpl_url}/images/restaurant_thumb.jpg" alt="" width="91" height="52" /></td>
                                     <td width="590" align="left" valign="top"><table width="100%" border="0" cellspacing="0" cellpadding="0">
                                         <tr>
                                           <td width="80%" height="22" class="head01">Lorem ipsum dolor sit amet, consectetur </td>
                                           <td width="20%" class="normal_bold">&nbsp;</td>
                                         </tr>
                                         <tr>
                                           <td>Lorem ipsum dolor sit amet, consectetur <br />
                                             dolor sit amet, consectetur <br />
                                           </td>
                                           <td><a href="#" class="selectBtn"><span>Select</span></a></td>
                                         </tr>
                                     </table></td>
                                   </tr>
                                 </table></td>
                               </tr>
                               <tr>
                                 <td class="sep_dotline"></td>
                               </tr>
                               <tr>
                                 <td align="left" valign="top"><table width="700" border="0" cellspacing="0" cellpadding="0">
                                   <tr>
                                     <td width="110" align="left" valign="top"><img src="{$GLOBAL.tpl_url}/images/restaurant_thumb.jpg" alt="" width="91" height="52" /></td>
                                     <td width="590" align="left" valign="top"><table width="100%" border="0" cellspacing="0" cellpadding="0">
                                         <tr>
                                           <td width="80%" height="22" class="head01">Lorem ipsum dolor sit amet, consectetur </td>
                                           <td width="20%" class="normal_bold">&nbsp;</td>
                                         </tr>
                                         <tr>
                                           <td>Lorem ipsum dolor sit amet, consectetur <br />
                                             dolor sit amet, consectetur <br />
                                           </td>
                                           <td><a href="#" class="selectBtn"><span>Select</span></a></td>
                                         </tr>
                                     </table></td>
                                   </tr>
                                 </table></td>
                               </tr>
                               <tr>
                                 <td class="sep_dotline"></td>
                               </tr>

                               <tr>
                                 <td align="left" valign="top">&nbsp;</td>
                               </tr>
                             </table>
						   </div> 
						   <div class="form_row_field">
						  <table width="363" border="0" align="left" cellpadding="0" cellspacing="0">
                            <tr>
                              <td width="153">&nbsp;</td>
                              <td width="210"><a class="top_btn" href="#"><span>Create New </span></a></td>
                            </tr>
                          </table>
						</div>-->
						</div>
					    <div class="clear"></div>
				    </div>
				  </div>
				  
					<div class="profile_wrap_bottom02"><!-- --></div>
					
				</div>	
				<div class="clear"></div>
				<div class="padding08"><!-- --></div>			
				</div>
				<div class="clear"></div>
			</div>
			
		
		</div>