<script type="text/javascript" src="{$smarty.const.SITE_URL}/includes/photogallery/FancyZoom.js"></script>
<script type="text/javascript" src="{$smarty.const.SITE_URL}/includes/photogallery/FancyZoomHTML.js"></script>
{literal}
 <script type="text/javascript">
 
    var map;
    var gdir;
    var geocoder = null;
    var addressMarker;

    function initialize() { 
      if (GBrowserIsCompatible()) {      
        map = new GMap2(document.getElementById("map_canvas"));
		
		
        gdir = new GDirections(map, document.getElementById("directions"));
        GEvent.addListener(gdir, "load", onGDirectionsLoad);
        GEvent.addListener(gdir, "error", handleErrors);

        setDirections('{/literal}{$LOCATION_ADDRESS}{literal}', '{/literal}{$LOCATION_ADDRESS}{literal}', "en_US");
      }
    }
    
    function setDirections(fromAddress, toAddress, locale) {
      gdir.load("from: " + fromAddress + " to: " + toAddress,
                { "locale": "en_US" });
    }

    function handleErrors(){
	   if (gdir.getStatus().code == G_GEO_UNKNOWN_ADDRESS)
	     alert("No corresponding geographic location could be found for one of the specified addresses. This may be due to the fact that the address is relatively new, or it may be incorrect.\nError code: " + gdir.getStatus().code);
	   else if (gdir.getStatus().code == G_GEO_SERVER_ERROR)
	     alert("A geocoding or directions request could not be successfully processed, yet the exact reason for the failure is not known.\n Error code: " + gdir.getStatus().code);
	   
	   else if (gdir.getStatus().code == G_GEO_MISSING_QUERY)
	     alert("The HTTP q parameter was either missing or had no value. For geocoder requests, this means that an empty address was specified as input. For directions requests, this means that no query was specified in the input.\n Error code: " + gdir.getStatus().code);

	//   else if (gdir.getStatus().code == G_UNAVAILABLE_ADDRESS)  <--- Doc bug... this is either not defined, or Doc is wrong
	//     alert("The geocode for the given address or the route for the given directions query cannot be returned due to legal or contractual reasons.\n Error code: " + gdir.getStatus().code);
	     
	   else if (gdir.getStatus().code == G_GEO_BAD_KEY)
	     alert("The given key is either invalid or does not match the domain for which it was given. \n Error code: " + gdir.getStatus().code);

	   else if (gdir.getStatus().code == G_GEO_BAD_REQUEST)
	     alert("A directions request could not be successfully parsed.\n Error code: " + gdir.getStatus().code);
	    
	   else alert("An unknown error occurred.");
	   
	}

	function onGDirectionsLoad(){ 
      // Use this function to access information about the latest load()
      // results.

      // e.g.
      // document.getElementById("getStatus").innerHTML = gdir.getStatus().code;
	  // and yada yada yada...
	}
    </script>
{/literal}
<script type="text/javascript">
{literal}
	window.onload = function () {
		setupZoom(); 
		if('{/literal}{$smarty.request.tab}{literal}' == '5')
		{ 
			initialize();
		}
	}
	window.onunload = function() {
			if('{/literal}{$smarty.request.tab}{literal}' == '5')
			{ 
				GUnload();
			}
	}
	
{/literal}	
</script>
<script language="javascript" src="{$smarty.const.SITE_URL}/scripts/jquery.js" type="text/javascript"></script>
<script src="{$smarty.const.SITE_URL}/scripts/jquery.curvycorners.packed.js" type="text/javascript"></script>
<script language="javascript" type="text/javascript" src="{$smarty.const.SITE_URL}/scripts/popup_new.js"></script>
<script language="javascript" type="text/javascript" src="{$smarty.const.SITE_URL}/includes/ajax/ajax.js"></script>
{if $smarty.request.tab eq '5'}
<script src=" http://maps.google.com/?file=api&amp;v=2.x&amp;key={$GOOGLE_MAP_KEY}" type="text/javascript"></script>
{/if}
 

{literal}
<script language="javascript">
$(function()
{	
	$('.popup').corner();
	
	document.getElementById('email_friend').style.display ="none";	
	
	
	
	
});

function closePopup(name,divName)
{
	
	divName ='#' + divName;
	$(divName).slideUp(650,function(){
		popupPosition_Hide(name);
	});
	
	
	
	
	
	
	
}



function showPopup(name,evt,divName,x,y)
{

	popupPosition_visible(name,evt,1,x,y);
	divName ='#' + divName;
	$(divName).slideDown(650);
}
/*function showPopup(name,450,650,divName)
{

	popupPosition_visible(name,evt,1);
	divName ='#' + divName;
	$(divName).slideDown(650);
	
	
}*/
function sendtofriend(form)
{
	var name 			= document.frmfriend.name.value;
	var email  			= document.frmfriend.email.value;
	
	
	var email_addresses    	= document.frmfriend.emailaddresses.value;
	var message				= document.frmfriend.message.value;
	
	
	
	var flyer_id         			= "{/literal}{$smarty.request.flyer_id}{literal}";

	
	
		document.getElementById('but_profile_div').style.display = 'none';
		document.getElementById('load_profile_div').style.display = "inline";
		//document.getElementById('div_name').innerHTML=first_name+' '+last_name;
		
		var req1 = newXMLHttpRequest();
		req1.onreadystatechange = getReadyStateHandler(req1, serverResProfile);
		str= "name="+name+"&email="+email+"&emailaddresses="+email_addresses+"&message="+message+"&flyer_id="+flyer_id; 
		
		{/literal}
		req1.open("POST", "{makeLink mod=flyer pg=preview}act=forwardform{/makeLink}&"+Math.random());
		{literal}
		req1.setRequestHeader("Content-Type","application/x-www-form-urlencoded; charset=UTF-8");
		req1.send(str);
		
	
}

function serverResProfile(_var) {

	closePopup('email_friend','slideDivFriend');
	document.getElementById('but_profile_div').style.display = "inline";
	document.getElementById('load_profile_div').style.display = "none";
}	










function showCompleteReview()
{
	document.getElementById('div_review').style.display='none'
	document.getElementById('div_review_complete').style.display='block'
}
function showLatestReview()
{
	document.getElementById('div_review_complete').style.display='none'
	document.getElementById('div_review').style.display='block'
}
function valideform()
{ 
	if(document.frm_review.title.value == '')
	{
		alert('Please enter Review title');
		return false;
	}
	else if(document.frm_review.price.value =='')
	{
		alert('Please enter Rating price');
		return false;
	}
	else if(document.frm_review.food.value =='')
	{
		alert('Please enter Rating Food');
		return false;
	}
	else if(document.frm_review.service.value =='')
	{
		alert('Please enter Rating Service');
		return false;
	}
	else if(document.frm_review.environment.value =='')
	{
		alert('Please enter Rating Environment');
		return false;
	}
	else if(document.frm_review.comments.value =='')
	{
		alert('Please enter Rating Comments');
		return false;
	}
	else
	{
		document.frm_review.submit();
		return true;
	}
}
function claimRestaurant(flyer_id)
{ 
	user_id	=	'{/literal}{$smarty.session.memberid}{literal}';
	if(user_id != '')
	{
		location.href='{/literal}{makeLink mod=flyer pg=list}act=select_pack&restauranteur_id='+user_id+'&flyer_id='+flyer_id+'{/makeLink}{literal}';
	}
}

function submit_flyer()
{
{/literal}{if $smarty.request.from eq 'admin'}{literal}
document.frm_flyer.action = "{/literal}{makeLink mod=flyer pg=admin_list}act=flyer_form&form_id=1&flyer_id={$smarty.request.flyer_id}{/makeLink}{literal}"
{/literal}{else}{literal}
document.frm_flyer.action = "{/literal}{makeLink mod=flyer pg=list}act=flyer_form&form_id=1&flyer_id={$smarty.request.flyer_id}{/makeLink}{literal}"
{/literal}{/if}{literal}

document.frm_flyer.submit();
}


</script>
{/literal}
<div class="top_banner">{$TOP_MAIN_BANNER}</div>
<div id="inner_mid" style="padding-bottom:0px;">
		<!-- START:Left Wrap-->
		<div class="left_wrap01">
			<div class="right_top_bg"><!-- --></div>
			
		<!-- Start: Inner Left Wrap -->
		<div class="padding_11">
			<!-- Start: Head Nav -->
			<div style="padding-bottom:5px;" >
			  <table width="200" border="0" align="right" cellpadding="0" cellspacing="0">
                <tr><form name="frm_flyer"  method="post" action=""><input type="hidden" name="btn_publish_x" value="1"><input type="hidden" name="flyer_id" value="{$smarty.request.flyer_id}"><input type="hidden" name="form_id" value="1"><input type="hidden" name="flyer_preview" value="1">
                  <td align="left"><a href="#" onClick="history.go(-1);"><img src="{$GLOBAL.tpl_url}/images/btn_back.jpg" alt="" width="81" height="28" border="0" /></a></td>
                  <td align="right"><a href="#" onClick="submit_flyer();"><img src="{$GLOBAL.tpl_url}/images/btn_publish.jpg" alt="" width="101" height="28" border="0" /></a></td>
                </form>
				</tr>
              </table>
			  <div class="clear"></div>
			</div>	
			<div class="head_wrap01">	
				<div class="head_wrap01_inner">
					<div class="page_nav">
						{$FLYER_PATH}
						<div class="clear"></div>
									
						<span class="head_style01"  >{$FLYER_DATA.title}</span>
						<span class="head_style03 padding_10">{$FLYER_DATA.ContactInfo.location_street_address}
						{if $FLYER_DATA.ContactInfo.location_city ne '' }, {$FLYER_DATA.ContactInfo.location_city|lower|capitalize}{/if}
						{if $FLYER_DATA.ContactInfo.location_state ne '' }, {$FLYER_DATA.ContactInfo.location_state|lower|capitalize}{/if}
						</span>		
					
					</div>
					<div class="clear"></div>
				</div>	
					
				<div class="click_icon">{if $FLYER_DATA.package_id ne '0' && $FLYER_DATA.package_id ne '' && $SHOW_RESERVATION gt 0}<img src="{$GLOBAL.tpl_url}/images/click_icon.jpg" alt=""  />{/if}</div>
			<div class="clear"></div>
			</div>
			<!-- End: Head Nav -->
			
			<!-- Start: Restaurant Profile-->
			<div class="restaurant_profile">
				<div class="img_wrap">
				{if $FLYER_DATA.image ne '' }
				<img src="{$GLOBAL.modbase_url}/flyer/images/slide/{$FLYER_DATA.image}" alt="{$FLYER_DATA.title}"  width="215" height="215" class="img_style"/>
				{else}
				<img src="{$GLOBAL.modbase_url}/flyer/images/default215.jpg" alt="{$FLYER_DATA.title}"  width="215" height="215" class="img_style"/>
				{/if}
				</div>
				
				<div class="restaurant_content">
				<table width="300" border="0" cellspacing="0" cellpadding="0">
				
				<tr><td align="left" valign="top"><table  border="0" cellspacing="0" cellpadding="0">
                     <tr>
                        <td  height="30" align="left" valign="top" class="normal_bold1">Restaurant Profile</td>
						{if $INTERNET_ACCESS.0 eq   'Yes, Free Wi-Fi / Internet Access Available'}
                        <td width="30" align="right" valign="top"><img src="{$GLOBAL.tpl_url}/images/icon_wifi.jpg" alt="Wi-Fi / Internet Access" width="26" height="23" /></td>
						{/if}
                       {if $ALCOHOLIC_BEVERAGES.0 eq 'Beer/Wine'}
					    <td width="30" align="right" valign="top"><img src="{$GLOBAL.tpl_url}/images/icon_wine.jpg" alt="Beer/Wine" width="21" height="21" /></td>
						{/if}
						{if $ALCOHOLIC_BEVERAGES.0 eq 'Full Bar'}
                        <td width="30" align="right" valign="top"><img src="{$GLOBAL.tpl_url}/images/icon_bar.jpg" alt="Full Bar" width="18" height="21" /></td>
						{/if}
                        <td width="100" align="right" valign="top"><a href="#" class="normal_redlink_02">Email </a> |  <a href="#" class="normal_redlink_02">Website</a></td>
                      </tr>
                    </table></td>
				  </tr>
				
				
				 {if $FLYER_DATA.package_id ne '0' && $FLYER_DATA.package_id ne ''}
				  <tr>
					<td align="left" valign="top">
					<table width="300" border="0" cellspacing="0" cellpadding="0">
                      <tr>
                        <td width="173" height="30" align="left" valign="top" class="normal_bold1">Restaurant Profile</td>
                        <td width="127" align="right" valign="top">{if $FLYER_DATA.contact_email ne ''}<a href="mailto:{$FLYER_DATA.contact_email}" class="normal_redlink_02">Email </a>{/if}{if $FLYER_DATA.website ne ''} | <a href="{$FLYER_DATA.website}" target="_blank" class="normal_redlink_02">Website</a>{/if}</td>
                      </tr>
                    </table></td>
				  </tr>
				  <tr>
					<td height="140" align="left" valign="top">
					{$FLYER_DATA.description}</td>
				  </tr>
				  {else}
				  <tr>
					<td align="left" valign="top">
						<table width="300" border="0" cellspacing="0" cellpadding="0">
                     		 <tr>
                       			 <td height="170" align="center" valign="middle" class="normal_bold1">
								 <table width="100%" border="0" cellspacing="0" cellpadding="0">
								  <tr>
									<td width="46" height="46"><img src="{$GLOBAL.tpl_url}/images/claimnow_left.jpg" alt="" width="46" height="46" /></td>
									<td class="text_red_bold" style="background:url({$GLOBAL.tpl_url}/images/claimnow_bg.jpg) repeat-x; padding-left:3px;"><a href="#" onClick="javascript:claimRestaurant('{$FLYER_DATA.flyer_id}');"> Is This Your Restaurant? Claim it Now !</a></td>
									<td width="21" height="46" ><img src="{$GLOBAL.tpl_url}/images/claimnow_rht.jpg" alt="" width="21" height="46" /></td>
								  </tr>
                        		</table>
								</td>
                     		 </tr>
							</table>
							</td>
						</tr>
				  {/if}
				  <tr>
					<td align="left" valign="top"><table width="300" border="0" cellspacing="0" cellpadding="0">
                      <tr>
                        <td width="106" align="center" valign="top" class="normal_bold1">Overall Rating</td>
                        <td width="79" align="center" valign="top" class="normal_bold1">Price</td>
                        <td width="107" align="left" valign="top"  class="normal_bold1"> {if $FLYER_DATA.package_id ne '0' && $FLYER_DATA.package_id ne '' && $SHOW_RESERVATION gt 0} Make Reservation {/if}</td>
                      </tr>
                      <tr>
                        <td align="center" valign="middle">{if $FLYER_RATES.rate ne ''}<img src="{$GLOBAL.tpl_url}/images/rate{$FLYER_RATES.rate}.gif"  />{else}<img src="{$GLOBAL.tpl_url}/images/rate0.gif"  /> {/if}</td>
                        <td align="center" valign="middle">{if $FLYER_RATES.price ne ''}<img src="{$GLOBAL.tpl_url}/images/price{$FLYER_RATES.price}.gif"  />{else}<img src="{$GLOBAL.tpl_url}/images/price0.gif"  /> {/if}</td>
                        <td align="center" valign="middle"> {if $FLYER_DATA.package_id ne '0' && $FLYER_DATA.package_id ne '' && $SHOW_RESERVATION gt 0}<a href="{makeLink mod=flyer pg=list}act=reservation&flyer_id={$smarty.request.flyer_id}{/makeLink}"><img src="{$GLOBAL.tpl_url}/images/food_icon.jpg" alt="" width="38" height="32" border="0" /></a>{/if}</td>
                      </tr>
                    </table></td>
				  </tr>
				</table>
				</div>
				
				<div class="restaurant_hours" >
				<table width="130" border="0" cellspacing="0" cellpadding="0">
  <tr>
    <td class="normal_bold1">Hours of Operation</td>
  </tr>
  <tr>
    <td class="td3">
	Monday<br />
	{$HOURS_OF_OPERATION.Monday}
	</td>
  </tr>
  <tr>
    <td class="td4">Tuesday<br />
      {$HOURS_OF_OPERATION.Tuesday}</td>
  </tr>
  <tr>
    <td class="td3">
	Wednesday<br />
{$HOURS_OF_OPERATION.Wednesday}
	</td>
  </tr>
  <tr>
    <td class="td4">Thursday<br />
{$HOURS_OF_OPERATION.Thursday}
</td>
  </tr>
  <tr>
  <td class="td3">
	Friday<br />
{$HOURS_OF_OPERATION.Friday}
	</td>
  </tr>
  <tr>
    <td class="td4">
	Saturday<br />
{$HOURS_OF_OPERATION.Saturday}
	</td>
  </tr>
  <tr>
     <td class="td3">
	Sunday<br />
{$HOURS_OF_OPERATION.Sunday}
	</td>
  </tr>
</table>

				
				</div>
				
				<div class="clear"></div>
			</div>
			<!-- End: Restaurant Profile-->
			
			
			<!-- Start: User Profile-->
			
			<div class="text_small" ><table width="686" border="0" cellspacing="0" cellpadding="0">
               <tr style="background:#f4f3f3;">
                 <td width="159" height="25" align="center" class="normal_bold1">Cuisines</td>
                 <td width="115" align="center" class="normal_bold1">Meals</td>
                 <td width="263" align="center" class="normal_bold1">Features</td>
                 <td width="149" align="center" class="normal_bold1">Payment Methods </td>
               </tr>
               <tr>
                 <td  style="border-right:1px solid #dedcdc;  padding-left:10px;" valign="top"><table width="138" border="0" cellspacing="0" cellpadding="0">
                   <tr>
				    {assign var="col1" value="1"} 
					{foreach from=$CUISINES item=cuisines}
                     <td width="73" align="left" valign="top">{$cuisines}</td>
                      {if $col1%2 eq 0}	
                      </tr>
					  {/if}
					 {assign var="col1" value="`$col1+1`"} 
					   {/foreach}
                   
                   </tr>
                 </table></td>
                 <td  style="border-right:1px solid #dedcdc; padding-left:10px;" valign="top"><table width="89" border="0" cellspacing="0" cellpadding="0">
                    {foreach from=$SERVING item=servings}
				    <tr>
                      <td width="103" align="left" valign="top">{$servings}</td>
                    </tr>
					{/foreach}
                 </table></td>
                 <td  style="border-right:1px solid #dedcdc;  padding-left:10px;" valign="top"><table width="232" border="0" cellspacing="0" cellpadding="0">
            
                   <tr>
					 {assign var="col2" value="1"} 
					 {foreach from=$FEATURES item=features}
                      <td width="126" align="left" valign="top">{$features}</td>
					  {if $col2%2 eq 0}	
                      </tr>
					  {/if}
					 {assign var="col2" value="`$col2+1`"} 
					   {/foreach}
                    </tr>
                 </table></td>
                 <td width="145" align="center">
				 <table width="100%" border="0" cellspacing="2" cellpadding="0">
                   <tr>
				    {assign var="col6" value="1"} 
					 {foreach from=$PAYMENT item=payments} 
					  {assign var="my_logo_name" value=""}
					 {if $payments eq 'Cash'}  {assign var="my_logo_name" value="cash.jpg"}  {/if}
					 {if $payments eq 'MasterCard'}   {assign var="my_logo_name" value="card_master.jpg"}  {/if}
					 {if $payments eq 'Amex'} 	 {assign var="my_logo_name" value="card_amex.jpg"} 	 {/if}
					 {if $payments eq 'Discover'}  {assign var=my_logo_name value="card_discover.jpg"} {/if}
					 {if $payments eq 'Debit Card'}  {assign var=my_logo_name value="debit.jpg"} {/if}
					 {if $payments eq 'VISA' ||  $payments eq 'Visa'} {assign var=my_logo_name value="card_visa.jpg"} {/if}
					 {if $payments eq 'cheque'}  {assign var=my_logo_name value="cheque.jpg"} 	 {/if}
					   <td align="left" valign="top"><a href="#"><img src="{$GLOBAL.modbase_url}/order/images/paymenttype/{$my_logo_name}" alt="" width="43" height="27" border="0" /></a></td>
					  {if $col6%3 eq 0}	
					    </tr>
						<tr><td colspan="3" height="2"><!--&nbsp; --></td></tr>
					  {/if}
					 {assign var="col6" value="`$col6+1`"} 
					   {/foreach}
                    
                   </tr>
                  </table>
				</td>
               </tr>
             </table>
			<!-- </div> -->
			
			<!-- <div class="cusines_wrap"> -->
			  <!-- <table width="100%" border="0" cellspacing="0" cellpadding="5">
                <tr style="background:#f4f3f3;">
                  <td width="16%" height="26" align="left" valign="middle" bgcolor="#f4f3f3" class="normal_bold1">Cuisines</td>
                  <td width="20%" align="left" valign="middle" bgcolor="#f4f3f3" class="normal_bold1">Meals</td>
                  <td width="36%" align="left" valign="middle" bgcolor="#f4f3f3" class="normal_bold1">Features</td>
                  <td width="28%" align="left" valign="middle" bgcolor="#f4f3f3" class="normal_bold1">Payment Methods </td>
                </tr>
                <tr >
                  <td height="2" colspan="4" align="left" valign="middle" ></td>
                </tr>
                <tr>
                  <td align="left" valign="top" bgcolor="#FFFFFF" style="border-right:1px solid #dedcdc;"><table width="53%" border="0" cellspacing="0" cellpadding="0">
                    {foreach from=$CUISINES item=cuisines}
					<tr>
                      <td align="left" valign="top">{$cuisines}</td>
                    </tr>
					{/foreach}
                    </table></td>
                  <td align="left" valign="top" bgcolor="#FFFFFF" style="border-right:1px solid #dedcdc;"><table width="100%" border="0" cellspacing="0" cellpadding="0">
                   
				    {foreach from=$SERVING item=servings}
				    <tr>
                      <td align="left" valign="top">{$servings}</td>
                    </tr>
					{/foreach}
                 
                 
                  </table></td>
                  <td align="left" valign="top" bgcolor="#FFFFFF" style="border-right:1px solid #dedcdc;">
				  <table width="100%" border="0" cellspacing="0" cellpadding="0">
                    <tr>
					 {assign var="col2" value="1"} 
					 {foreach from=$FEATURES item=features}
                      <td width="51%" align="left" valign="top">{$features}</td>
					  {if $col2%2 eq 0}	
                      </tr>
					  {/if}
					 {assign var="col2" value="`$col2+1`"} 
					   {/foreach}
                    </tr>
                   
                  </table>
				  </td>
                  <td align="left" valign="top" bgcolor="#FFFFFF"><img src="{$GLOBAL.tpl_url}/images/payment_img.jpg" alt="" width="145" height="65" /></td>
                </tr>
              </table> -->
			 
			 <div style="padding-top:5px;">
			  <table width="100%" border="0" cellspacing="0" cellpadding="0" >
			  <tr>
				<td width="2%" align="left" valign="top"><img src="{$GLOBAL.tpl_url}/images/left_block.jpg" alt="" width="17" height="44" /></td>
				<td width="96%" align="left" valign="middle" style="background:url({$GLOBAL.tpl_url}/images/block_bg.jpg) repeat-x left top;"><table width="100%" border="0" cellspacing="0" cellpadding="0">
				  <tr>
					<td width="4%" align="left" valign="top"><img src="{$GLOBAL.tpl_url}/images/email_icon.jpg" alt="" width="17" height="17" /></td>
					<td width="15%" align="left" valign="middle"><a href="#" onClick="javascript:showPopup('email_friend','','slideDivFriend',280,320);return false;" class="small_text_link">Email to a friend</a></td>
					<td width="4%" align="left" valign="top"><img src="{$GLOBAL.tpl_url}/images/add_whishlist.jpg" alt="" width="21" height="21" /></td>
					<td width="16%" align="left" valign="middle"><a href="{makeLink mod=flyer pg=list}act=wish_list&flyer_id={$smarty.request.flyer_id}&tab={$smarty.request.tab}#tabs{/makeLink}" class="small_text_link">Add to Wishlist</a></td>
					<td width="5%" align="left" valign="middle"><img src="{$GLOBAL.tpl_url}/images/write_icon.jpg" alt="" width="21" height="21" /></td>
					<td width="15%" align="left" valign="middle"><a href="#" class="small_text_link">Write Review </a></td>
					<td width="4%" align="left" valign="middle"><img src="{$GLOBAL.tpl_url}/images/add_fav.jpg" alt="" width="17" height="17" /></td>
					<td width="16%" align="left" valign="middle"><a href="{makeLink mod=flyer pg=list}act=addtofavourite&flyer_id={$smarty.request.flyer_id}&tab={$smarty.request.tab}#tabs{/makeLink}" class="small_text_link">Add to Favourites</a></td>
					<td width="4%" align="left" valign="middle"><img src="{$GLOBAL.tpl_url}/images/print_icon.jpg" alt="" width="21" height="21" /></td>
					<td width="17%" align="left" valign="middle"><a href="javascript:window.print();" class="small_text_link">Print Page </a></td>
				  </tr>
				</table></td>
				<td  align="right" valign="top"><img src="{$GLOBAL.tpl_url}/images/rht_block.jpg" alt="" width="13" height="45" /></td>
			  </tr>
			</table>
			</div> 
			</div>
			<!-- End: User Profile-->
			<a name="tabs"></a>
			<!-- START: User Profile-->
			<div class="feature_wrap">
				<div style="width:686px; height:34px;">
				{if $SHOW_TAB1 eq 'Y' }<a href="{makeLink mod=flyer pg=list}act=flyer_details&flyer_id={$smarty.request.flyer_id}&tab=1#tabs{/makeLink}" class="tab_btn"><span>Videos</span></a>{/if}
				{if $SHOW_TAB2 eq 'Y' }<a href="{makeLink mod=flyer pg=list}act=flyer_details&flyer_id={$smarty.request.flyer_id}&tab=2#tabs{/makeLink}" class="tab_btn"><span>Pictures</span></a>{/if}
				{if $SHOW_TAB3 eq 'Y' }<a href="{makeLink mod=flyer pg=list}act=flyer_details&flyer_id={$smarty.request.flyer_id}&tab=3#tabs{/makeLink}" class="tab_btn"><span>Coupons</span></a>{/if}
				{if $SHOW_TAB4 eq 'Y' }<a href="{makeLink mod=flyer pg=list}act=flyer_details&flyer_id={$smarty.request.flyer_id}&tab=4#tabs{/makeLink}" class="tab_btn"><span>Chef's Profile</span></a>{/if}
				<a href="{makeLink mod=flyer pg=list}act=flyer_details&flyer_id={$smarty.request.flyer_id}&tab=5#tabs{/makeLink}" class="tab_btn"><span>Maps &amp; Directions</span></a>
				{if $SHOW_TAB6 eq 'Y' }<a href="{makeLink mod=flyer pg=list}act=flyer_details&flyer_id={$smarty.request.flyer_id}&tab=6#tabs{/makeLink}" class="tab_btn"><span>Restaurant Review</span></a>{/if}
				
				</div>
				<!-- google adds section starts here -->
				
				 <div class="feature_content_wrap">
				  {if $smarty.request.tab eq '1' or  $smarty.request.tab eq ''}
				  {if $SHOW_TAB1 eq 'Y' }
					 <div align="center" style="width:656px; vertical-align:middle;">
						{$FLYER_DATA.video_code}
					 </div>
				  {/if}
				 {elseif $smarty.request.tab eq '2'}
				 <!-- Photos section  -->
				 {if $SHOW_TAB2 eq 'Y' }
				  <div align="center" style="width:656px; vertical-align:middle;">
					  <table width="100%" border="0" cellspacing="0" cellpadding="0">
                    <tr>
					 {assign var="col3" value="1"} 
					 {foreach from=$FLYER_DATA.gallary item=photos}
                      <td width="50%" align="center" valign="top"><div align="center" style="width:343px;"> 
					  <!-- <img src="{$GLOBAL.modbase_url}/flyer/images/thumb/{$photos.image_name}" alt="{$photos.caption}" onclick="{$GLOBAL.modbase_url}/flyer/images/thumb/{$photos.image_name}" ondblclick="this.src='{$GLOBAL.modbase_url}/flyer/images/thumb/{$photos.image_name}"> -->
					 <a href="{$GLOBAL.modbase_url}/flyer/images/gallary/thumb/{$photos.image_name}?{$smarty.now}"> <img class="imgbdr" src="{$GLOBAL.modbase_url}/flyer/images/slide/{$photos.image_name}" alt="{$photos.caption}" /></a> </div>&nbsp;</td>
					  {if $col3%2 eq 0}	
                      </tr>
					  {/if}
					 {assign var="col3" value="`$col3+1`"} 
					   {/foreach}
                    </tr>
                   
                  </table>
				
					
					
				 </div>
				 {/if}
				 {elseif $smarty.request.tab eq '3'}
				 {if $SHOW_TAB3 eq 'Y' }
				  <div align="left" style="width:656px; vertical-align:middle;" align="left">
					<!-- start coupons -->
					<table width="661" border="0" cellspacing="0" cellpadding="0">
                    <tr>
					 {assign var="col4" value="1"} 
					{foreach from=$COUPON_DETAILS item=flyer_coupons}
                       <td width="331"  style="1px solid # "><table width="320" border="0" cellspacing="0" cellpadding="0" style="padding 0px auto" class="couponborder">
                        <tr>
                          <td height="22" class="coupon_head02">{$flyer_coupons.name}</td>
                        </tr>
                        <tr>
                          <td style="padding:2px;"><table width="100%" border="0" cellspacing="2" cellpadding="0">
                              <tr style="background:#f9f6f1;">
                                <td width="44%" height="20" align="left" valign="middle">Valid</td>
                                <td width="56%">{$flyer_coupons.valid_from|date_format:"%B %e %Y"} &nbsp;-&nbsp; {$flyer_coupons.valid_to|date_format:"%B %e %Y"}</td>
                              </tr>
                            <!--   <tr style="background:#f0ede9;">
                                <td height="20">Days Available </td>
                                <td align="left" valign="middle">Any day of the week </td>
                              </tr> -->
                              <tr style="background:#f9f6f1;">
                                <td height="20">Time Available </td>
                                <td align="left" valign="middle">{$flyer_coupons.time_avilable_from|date_format:"%r "}&nbsp;- &nbsp;{$flyer_coupons.time_avilable_to|date_format:"%r"} </td>
                              </tr>
                              <tr style="background:#f0ede9;">
                                <td height="20" align="left" valign="middle">Coupon Required : No </td>
                                <td>{$flyer_coupons.coupon_required}</td>
                              </tr>
                              <tr style="background:#f9f6f1;">
                                <td height="20" align="left" valign="middle">Cuisines</td>
                                <td>{$flyer_coupons.cuisines}</td>
                              </tr>
                          </table></td>
                        </tr>
                        <tr>
                          <td class="coupon_rule"><span>Rules: </span>{$flyer_coupons.rules}</td>
                        </tr>
						<tr>
                          <td height="20" class="print"><a href="{makeLink mod=flyer pg=list}act=coupon_details&coupon_id={$flyer_coupons.id}{/makeLink}">Print this page</a></td>
                        </tr>
                      </table>					  </td> 
					   {if $col4%2 eq 0}	
                      </tr>
					   <tr>
                      <td>&nbsp;</td>
                      <td>&nbsp;</td>
                    </tr>
					  {/if}
                   {assign var="col4" value="`$col4+1`"} 
				{/foreach}
                    </tr>
                   
                    
                  </table>
					<!-- end coupons -->
					
					
					
					
					
					
					
					
					
					
					
					 
					{/if}
				 </div>
				 {elseif $smarty.request.tab eq '4'}
				 <!-- Chef's Profile -->
				 {if $SHOW_TAB4 eq 'Y' }
				 <div align="left" style="width:656px; vertical-align:middle;">
					{$CHEF_PROFILE}
				 </div>
				 {/if}
				  {elseif $smarty.request.tab eq '6'}
				 <!-- Restauranter review -->
				 {if $SHOW_TAB6 eq 'Y' }
				 <div align="left" style="width:656px; vertical-align:middle;">
					{$RESTAURNT_REVIEW}
				 </div>
				 {/if}
				 {elseif $smarty.request.tab eq '5'}
				
				
					
				 
				 <table width="650" border="0">
				 <tr><td colspan="2">
						<form action="#">
						<table width="657">
						<tr><td colspan="5">
						<strong>{$FLYER_DATA.ContactInfo.contact_name} </strong>
						 {if $FLYER_DATA.ContactInfo.location_street_address ne  ''}
							<br/>{$FLYER_DATA.ContactInfo.location_street_address}
						 {/if}
						  {if $FLYER_DATA.ContactInfo.location_city ne  ''}
							<br/>{$FLYER_DATA.ContactInfo.location_city}
						  {/if}
						 {if $FLYER_DATA.ContactInfo.location_state ne  ''}
							<br/>{$FLYER_DATA.ContactInfo.location_state}
						  {/if}
						   {if $FLYER_DATA.ContactInfo.location_country ne  ''}
							<br/>{$FLYER_DATA.ContactInfo.location_country}
						  {/if}
						  {if $FLYER_DATA.ContactInfo.contact_phone ne  ''}
							<br/>{$FLYER_DATA.ContactInfo.contact_phone}
						  {/if}
						  {if $FLYER_DATA.ContactInfo.contact_email ne  ''}
							<br/>{$FLYER_DATA.ContactInfo.contact_email}
						  {/if}
						</td></tr>
						<tr><th width="44" align="right"> From:&nbsp;</th>
						
						<td width="150"><input type="text" size="25" id="fromAddress" name="from" value="" class="text_field"/></td>
						
						<th width="35" align="right">&nbsp;&nbsp; To:&nbsp;</th>
						<td width="183" align="right"> <input type="text" size="25" id="toAddress" name="to" value="{$LOCATION_ADDRESS}" readonly="readonly" class="text_field" /> </td>
						<td width="221">&nbsp;&nbsp;<input name="submit" type="button" value="Get Directions" onclick="setDirections(document.getElementById('fromAddress').value, document.getElementById('toAddress').value, ''); return false" />
</td>
						</tr>
						
						
						</table>
						</form>
				 </td></tr>
				<tr>
				<td  colspan="2">
				<table class="directions" align="center">
								
				<tr>
				<td width="250" valign="top"><div id="directions" style="width: 245px; height: 350px; overflow:auto;"></div></td>
				
				<td width="400" valign="top"><div id="map_canvas" style="width: 400px; height: 350px;"></div></td>
				
				</tr>
				</table>
				</td>
				</tr>
				</table> 
				
					<!-- <div class="feature_wrap_left">
					{if $SHOW_TAB5 eq 'Y' }
					<table width="100%" border="0" cellspacing="0" cellpadding="0">
  <tr>
    <td><strong>{$FLYER_DATA.ContactInfo.contact_name} </strong></td>
  </tr>
  {if $FLYER_DATA.ContactInfo.location_street_address ne  ''}
  <tr>
    <td>{$FLYER_DATA.ContactInfo.location_street_address}</td>
  </tr>
  {/if}
  {if $FLYER_DATA.ContactInfo.location_city ne  ''}
  <tr>
    <td>{$FLYER_DATA.ContactInfo.location_city}</td>
  </tr>
  {/if}
   {if $FLYER_DATA.ContactInfo.location_state ne  ''}
  <tr>
    <td>{$FLYER_DATA.ContactInfo.location_state}</td>
  </tr>
  {/if}
   {if $FLYER_DATA.ContactInfo.location_country ne  ''}
  <tr>
    <td>{$FLYER_DATA.ContactInfo.location_country}</td>
  </tr>
  {/if}
   {if $FLYER_DATA.ContactInfo.contact_phone ne  ''}
  <tr>
    <td>{$FLYER_DATA.ContactInfo.contact_phone}</td>
  </tr>
  {/if}
   {if $FLYER_DATA.ContactInfo.contact_email ne  ''}
  <tr>
    <td>{$FLYER_DATA.ContactInfo.contact_email}</td>
  </tr>
  {/if}
  <tr>
    <td><strong>&nbsp;</strong></td>
  </tr>
 
  <tr>
    <td>&nbsp;</td>
  </tr>
  <tr>
    <td>&nbsp;</td>
  </tr>
  <tr>
    <td><strong>Get Directions</strong></td>
  </tr>
  <tr>
    <td><label>
      <input name="textfield3" type="text" value="--Enter Your Zip Code or City Name--"  class="text_field_form01" />
    </label></td>
  </tr>
</table>
{/if}
				  </div> -->
					
					<!-- <div class="img_wrap2">
					 <div class="google_map_wrap">
											<div class="google_map_top"></div>
											<div class="google_map_bg"> 
											<iframe id="map_view" src="{$GLOBAL.site_url}/index.php?mod=flyer&pg=preview&act=show_gmap&flyer_id={$smarty.request.flyer_id}" height="235px" width="224px" scrolling="no" frameborder="0" marginheight="0px" marginwidth="0px"></iframe>
											 </div>
					</div>
					
					</div> -->
					<div class="clear"></div>
				{/if}
				
				
				</div> 
				
				<!-- google adds section ends here -->
			</div>		
			<!-- END: User Profile-->
			
			
			<!-- Start: Review wrap -->
			<div class="review_wrap" >
			   <div id="div_review">
				<div class="review_wrap_head">
					<div class="text_head_bold" style="float:left;">User Reviews</div>
					<div style="float:right;" ><span class="text_bold1">Displaying {$FLYER_REVIEWS_COUNT} of {$COMPLETE_REVIEWS_COUNT} reviews</span>  <!-- |  <a href="#" class="normal_redlink_bold1">Add Review</a> --></div>
					<div class="clear"></div>
				</div>
				{foreach from=$FLYER_REVIEWS item=reviews}
				<div class="review_wrap_content">
					<div class="review_left">
					  <table width="100%" border="0" cellspacing="0" cellpadding="0">
                        <tr>
                          <td height="20" colspan="2" align="left" valign="top" class="head01">{$reviews.title|truncate:25}</td>
                        </tr>
                        <tr>
                          <td width="39%" align="left" valign="top">
						 {if $reviews.image ne 'N'}
						<img src="{$GLOBAL.modbase_url}member/images/userpics/thumb/{$reviews.user_id}.jpg" alt="{$reviews.first_name}"  width="50" height="50" class="img_style"/>
						{else}
						<img src="{$GLOBAL.modbase_url}member/images/photos/default.jpg" alt="{$reviews.first_name}" width="50" height="50"  class="img_style"/>
						{/if}
						  </td>
                          <td width="61%" align="left" valign="top">
						  <table width="100" border="0" cellspacing="0" cellpadding="0">
  <tr>
    <td><strong>{$reviews.first_name|truncate:20}</strong></td>
  </tr>
  <tr>
    <td>{$reviews.city}</td>
  </tr>
  <tr>
    <td>{$reviews.postalcode}</td>
  </tr>
</table>

					      </td>
                        </tr>
                      </table>
					</div>
					
					<div class="review_right">
					  <table width="100%" border="0" cellspacing="0" cellpadding="0">
  <tr>
    <td align="right" valign="top" class="grey_text">Reviewed on {$reviews.date|date_format:"%A,  %e %B %Y"}</td>
  </tr>
  <tr>
    <td align="left" valign="top">{$reviews.comments}</td>
  </tr>
  <tr>
    <td height="25" align="right" valign="top"><!-- <a href="#" class="normal_redlink_bold1">Read Full Review </a> -->&nbsp;</td>
  </tr>
  <tr>
    <td><table width="100%" border="0" cellspacing="3" cellpadding="0">
  <tr>
    <td width="87" class="normal_bold1">Price</td>
    <td width="15" rowspan="2" align="center" class="line_bg2">&nbsp;</td>
    <td width="79" class="normal_bold1">Overall rating </td>
    <td width="15" rowspan="2" class="line_bg2">&nbsp;</td>
    <td width="74" class="normal_bold1">Food</td>
    <td width="15" rowspan="2" class="line_bg2">&nbsp;</td>
    <td width="68" class="normal_bold1">Service
    <td width="21" rowspan="2" class="line_bg2">&nbsp;</td>
    <td width="101" class="normal_bold1">Environment</td>
  </tr>
  <tr>
    <td>{if $reviews.price ne ''}<img src="{$GLOBAL.tpl_url}/images/price{$reviews.price}.gif"  />{else}<img src="{$GLOBAL.tpl_url}/images/price0.gif"  /> {/if}</td>
    <td>{if $reviews.rate ne ''}<img src="{$GLOBAL.tpl_url}/images/rate{$reviews.rate}.gif"  />{else}<img src="{$GLOBAL.tpl_url}/images/rate0.gif"  /> {/if}</td>
    <td>{$reviews.food|string_format:"%.1f"}</td>
    <td>{$reviews.service|string_format:"%.1f"}</td>
    <td>{$reviews.environment|string_format:"%.1f"}</td>
  </tr>
</table>
</td>
  </tr>
</table>

					</div>
					
					<div class="clear"></div>
				</div>
				{/foreach}
				
				
				<div class="padding_text"><a href="javascript:void(0);"  class="normal_redlink_bold1" onClick="javascript:showCompleteReview();">View all archives</a></div>
				</div>
				
			</div>
			<!--End: Review wrap -->
			<!-- Complate Review starts here -->
			<div class="review_wrap" >
			<div id="div_review_complete"  style="display:none; ">
				<div class="review_wrap_head">
					<div class="text_head_bold" style="float:left;">User Reviews</div>
					<div style="float:right;" ><span class="text_bold1">Displaying {$COMPLETE_REVIEWS_COUNT} of {$COMPLETE_REVIEWS_COUNT} reviews</span>  <!-- |  <a href="#" class="normal_redlink_bold1">Add Review</a> --></div>
					<div class="clear"></div>
				</div>
				{foreach from=$COMPLETE_REVIEWS item=reviews}
				<div class="review_wrap_content">
					<div class="review_left">
					  <table width="100%" border="0" cellspacing="0" cellpadding="0">
                        <tr>
                          <td height="20" colspan="2" align="left" valign="top" class="head01">{$reviews.title|truncate:25}</td>
                        </tr>
                        <tr>
                          <td width="39%" align="left" valign="top">
						 {if $reviews.image ne 'N'}
						<img src="{$GLOBAL.modbase_url}member/images/userpics/thumb/{$reviews.user_id}.jpg" alt="{$reviews.first_name}"  width="50" height="50" class="img_style"/>
						{else}
						<img src="{$GLOBAL.modbase_url}member/images/photos/default.jpg" alt="{$reviews.first_name}" width="50" height="50"  class="img_style"/>
						{/if}
						  </td>
                          <td width="61%" align="left" valign="top">
						  <table width="100" border="0" cellspacing="0" cellpadding="0">
  <tr>
    <td><strong>{$reviews.first_name|truncate:20}</strong></td>
  </tr>
  <tr>
    <td>{$reviews.city}</td>
  </tr>
  <tr>
    <td>{$reviews.postalcode}</td>
  </tr>
</table>

					      </td>
                        </tr>
                      </table>
					</div>
					
					<div class="review_right">
					  <table width="100%" border="0" cellspacing="0" cellpadding="0">
  <tr>
    <td align="right" valign="top" class="grey_text">Reviewed on {$reviews.date|date_format:"%A,  %e %B %Y"}</td>
  </tr>
  <tr>
    <td align="left" valign="top">{$reviews.comments}</td>
  </tr>
  <tr>
    <td height="25" align="right" valign="top"><!-- <a href="#" class="normal_redlink_bold1">Read Full Review </a> -->&nbsp;</td>
  </tr>
  <tr>
    <td><table width="100%" border="0" cellspacing="3" cellpadding="0">
  <tr>
    <td width="87" class="normal_bold1">Price</td>
    <td width="15" rowspan="2" align="center" class="line_bg2">&nbsp;</td>
    <td width="79" class="normal_bold1">Overall rating </td>
    <td width="15" rowspan="2" class="line_bg2">&nbsp;</td>
    <td width="74" class="normal_bold1">Food</td>
    <td width="15" rowspan="2" class="line_bg2">&nbsp;</td>
    <td width="68" class="normal_bold1">Service
    <td width="21" rowspan="2" class="line_bg2">&nbsp;</td>
    <td width="101" class="normal_bold1">Environment</td>
  </tr>
  <tr>
    <td>{if $reviews.price ne ''}<img src="{$GLOBAL.tpl_url}/images/price{$reviews.price}.gif"  />{else}<img src="{$GLOBAL.tpl_url}/images/price0.gif"  /> {/if}</td>
    <td>{if $reviews.rate ne ''}<img src="{$GLOBAL.tpl_url}/images/rate{$reviews.rate}.gif"  />{else}<img src="{$GLOBAL.tpl_url}/images/rate0.gif"  /> {/if}</td>
    <td>{$reviews.food|string_format:"%.1f"}</td>
    <td>{$reviews.service|string_format:"%.1f"}</td>
    <td>{$reviews.environment|string_format:"%.1f"}</td>
  </tr>
</table>
</td>
  </tr>
</table>

					</div>
					
					<div class="clear"></div>
				</div>
				{/foreach}
				
				
				<div class="padding_text"><a href="javascript:void(0);"  class="normal_redlink_bold1" onClick="javascript:showLatestReview();">Show Latest</a></div>
				</div>
				{if $smarty.session.memberid ne ''}
				<form name="frm_review" method="post" action="">
				<table width="100%" border="0" cellspacing="6" cellpadding="0">
                    <tr>
                      <td align="left" valign="middle" class="normal_bold1"><span class="name_wrap_field">Review title</span></td>
                      <td align="left" valign="middle"><input type="text"  name="title" class="text_field_form02" style="width:200px;" /></td>
                    </tr>
                    <tr>
                      <td width="23%" align="left" valign="middle" class="normal_bold1"><span class="name_wrap_field">Ratings</span></td>
                      <td width="77%" align="left" valign="middle"> </td>
                    </tr>
                    <tr>
                      <td align="left" valign="middle" class="normal_bold1"><span class="name_wrap_field">Price</span></td>
                      <td align="left" valign="middle">
					  <select name="price" class="text_field_form02" style="width:210px;">
									  <option value="1">1.0</option>
									  <option value="2">2.0</option>
									  <option value="3">3.0</option>
									  <option value="4">4.0</option>
									  <option value="5">5.0</option>
                                      </select></td>
                    </tr>
                    <tr>
                      <td align="left" valign="middle" class="normal_bold1"><span class="name_wrap_field">Food</span></td>
                      <td align="left" valign="middle"><select name="food" class="text_field_form02" style="width:210px;">
									  <option value="1">1.0</option>
									  <option value="2">2.0</option>
									  <option value="3">3.0</option>
									  <option value="4">4.0</option>
									  <option value="5">5.0</option>
									  </select></td>
                    </tr>
                    <tr>
                      <td align="left" valign="middle" class="normal_bold1"><span class="name_wrap_field">Service</span></td>
                      <td align="left" valign="middle"> <select name="service" class="text_field_form02" style="width:210px;">
									  <option value="1">1.0</option>
									  <option value="2">2.0</option>
									  <option value="3">3.0</option>
									  <option value="4">4.0</option>
									  <option value="5">5.0</option>
									  </select></td>
                    </tr>
                    <tr>
                      <td align="left" valign="middle" class="normal_bold1"><span class="name_wrap_field">Environment</span></td>
                      <td align="left" valign="middle"> <select name="environment" class="text_field_form02" style="width:210px;">
								  <option value="1">1.0</option>
								  <option value="2">2.0</option>
								  <option value="3">3.0</option>
								  <option value="4">4.0</option>
								  <option value="5">5.0</option>
                                 </select></td>
                    </tr>
                    <tr>
                      <td align="left" valign="top" class="normal_bold1"><span class="name_wrap_field">Comments</span></td>
                      <td align="left" valign="middle"> <textarea name="comments" class="text_area" style="width:200px;height:70px;"></textarea>
								  <input type="hidden" name="flyer_id" value="{$smarty.request.flyer_id}"></td>
                    </tr>
                    <tr>
                      <td colspan="2" align="left" valign="middle" class="normal_bold1" height="5"><!-- --></td>
                    </tr>
                    <tr>
                      <td align="left" valign="middle" class="normal_bold1">&nbsp;</td>
                      <td align="left" valign="middle"> <a href="javascript:void(0);" class="redButton" onClick="javascript:valideform();"><span>Submit</span>					</td>
                    </tr>
                  </table>
				<!-- <div style="padding:10px 0px 0px 0px;">
				<span class="head03" style="padding-bottom:12px; display:block;">Add new review </span>
				<div class="form_row_field">
							<div class="form_row_field_01">
								<div class="form_wrap_field" >
									<div class="name_wrap_field">Review title</div>
									<div class="field_wrap_form"><input type="text"  name="title" class="text_field_form02" style="width:200px;" />
									</div>
								</div>
						   </div>
						  <div class="clear"></div>
						  
						  <div class="form_row_field_01">
							   <div class="form_wrap_field" >
									<div class="name_wrap_field">Ratings</div>
									<div class="field_wrap_form">
									  <label></label>
									</div>
							  </div>
						  </div>
						  <div class="clear"></div>
						  
						  <div class="form_row_field_01">
							  <div class="form_wrap_field" >
									<div class="name_wrap_field">Price</div>
									<div class="field_wrap_form">
									  <select name="price" class="text_field_form02" style="width:210px;">
									  <option value="1">1.0</option>
									  <option value="2">2.0</option>
									  <option value="3">3.0</option>
									  <option value="4">4.0</option>
									  <option value="5">5.0</option>
                                      </select>
									</div>
							  </div>
							</div>
						  <div class="clear"></div>
						  
						  <div class="form_row_field_01">
							  <div class="form_wrap_field" >
									<div class="name_wrap_field">Food</div>
								<div class="field_wrap_form">
									  <select name="food" class="text_field_form02" style="width:210px;">
									  <option value="1">1.0</option>
									  <option value="2">2.0</option>
									  <option value="3">3.0</option>
									  <option value="4">4.0</option>
									  <option value="5">5.0</option>
									  </select>
									</div>
							  </div>
						  </div>
						  <div class="clear"></div>
						  
						  <div class="form_row_field_01">
							  <div class="form_wrap_field" >
									<div class="name_wrap_field">Service</div>
									<div class="field_wrap_form">
									  <select name="service" class="text_field_form02" style="width:210px;">
									  <option value="1">1.0</option>
									  <option value="2">2.0</option>
									  <option value="3">3.0</option>
									  <option value="4">4.0</option>
									  <option value="5">5.0</option>
									  </select>
									</div>
							  </div>
			      </div>
						  <div class="clear"></div>
						  
						   <div class="form_row_field_01">
						     <div class="form_wrap_field" >
									<div class="name_wrap_field">Environment</div>
							   <div class="field_wrap_form">
							     <select name="environment" class="text_field_form02" style="width:210px;">
								  <option value="1">1.0</option>
								  <option value="2">2.0</option>
								  <option value="3">3.0</option>
								  <option value="4">4.0</option>
								  <option value="5">5.0</option>
                                 </select>
							   </div>
						     </div>
						  </div>
						  <div class="clear"></div>
						  
						  <div class="form_row_field1" style="height:80px;">
							<div class="form_wrap_field" >
								<div class="name_wrap_field">Comments</div>
								<div class="field_wrap_form">
								  <label>
								  <textarea name="comments" class="text_area" style="width:200px;height:70px;"></textarea>
								  <input type="hidden" name="flyer_id" value="{$smarty.request.flyer_id}">
								  </label>
								</div>
							</div>
							<div class="message_holder" style="display:none;">
								<div class="error_message">
								Error Message goes Here
								</div>
							</div>
						</div>
						  
						  <div class="form_row_field1">
							<div class="form_wrap_field" >
								<div class="name_wrap_field"></div>
								<div style="float:left; padding-left:10px;">
								  <a href="javascript:void(0);" class="redButton" onClick="javascript:valideform();"><span>Submit</span></a>
								</div>
							</div>
							<div class="message_holder" style="display:none;">
								<div class="error_message">
								Error Message goes Here
								</div>
							</div>
						</div>
							
				  </div>
					 <div class="clear"></div>
				</div> -->
				
				</form>
				{/if}
			</div>
			<!-- Complete review ends here -->
			
			
			
		</div>
		<!-- End: Inner Left Wrap -->
				
				
				
			<div class="right_bottom_bg"><!-- --></div>
		</div>
		<!-- END:Left Wrap-->
		
		<!-- START:Right Wrap-->
		<div class="right_wrap01">
			<div class="rightbox_wrap">
				<div class="rightbox_top"><!-- --></div>
				<div class="padding_11">
							
								<span class="head_style01" style="float:inherit;">Nearby Offers &amp;
Coupons</span>
								<div class="line_bg" style="padding-top:0px;"><!-- --></div>
						{foreach from=$NEARBY_COUPONS item=nearbycoupon}
						<div class="raw01" style="width:190px;">
						<a  href="{makeLink mod=flyer pg=list}act=coupons&flyer_id={$nearbycoupon.flyer_id}{/makeLink}" border="0">
						{if $nearbycoupon.image ne ''} 
						 <img src="{$GLOBAL.modbase_url}/flyer/images/widget/thumb/{$nearbycoupon.image}" alt="{$nearbycoupon.title}"  class="img_style"/>
						{else}
						 <img src="{$GLOBAL.modbase_url}/flyer/images/widget/thumb/default.jpg" alt="{$nearbycoupon.title}"  class="img_style"/>
						{/if}</a>
							<div class="raw01_content" style="width:130px;">
							  <table width="130" border="0" cellspacing="0" cellpadding="0">
                                <tr>
                                  <td align="left" valign="top"><span class="normal_bold"><a  href="{makeLink mod=flyer pg=list}act=coupons&flyer_id={$nearbycoupon.flyer_id}{/makeLink}" border="0" class="normal_bold">{$nearbycoupon.title|truncate:20}</a></span><br />
                                  {$nearbycoupon.location_city}&nbsp;{$nearbycoupon.location_zip} </td>
                                </tr>
                                <tr>
                                  <td align="left" valign="top">{$nearbycoupon.description|truncate:60}</td>
                                </tr>
                              </table>
							</div>
						    <div class="clear"></div>
						<div class="line_bg" style="padding-top:0px;"><!-- --></div>
				  </div>
				  {/foreach}
					  
			  </div>
				
				<div class="rightbox_btm"><!-- --></div>
			</div>
			<div class="padding08"><!-- --></div>
			
			<div class="rightbox_wrap">
				<div class="rightbox_top"><!-- --></div>
				<div class="padding_11">
							
								<span class="head_style01" style="float:inherit;">Nearby Restaurants</span>
								<div class="line_bg" style="padding-top:0px;"><!-- --></div>
						{foreach from=$NEARBY_LISTINGS item=nearby}
						<div class="raw01" style="width:190px;">
						<a  href="{makeLink mod=flyer pg=list}act=flyer_details&flyer_id={$nearby.flyer_id}{/makeLink}" >
						{if $nearby.image ne ''} 
						 <img src="{$GLOBAL.modbase_url}/flyer/images/widget/thumb/{$nearby.image}" alt="{$nearby.title}"  width="50" height="50"class="img_style"/>
						{else}
						 <img src="{$GLOBAL.modbase_url}/flyer/images/widget/thumb/default.jpg" alt="{$nearby.title}"  width="50" height="50"class="img_style"/>
						{/if}
						</a>
				
							<div class="raw01_content" style="width:130px;">
							  <table width="130" border="0" cellspacing="0" cellpadding="0">
                                <tr>
                                  <td align="left" valign="top"><span class="normal_bold"><a  href="{makeLink mod=flyer pg=list}act=flyer_details&flyer_id={$nearby.flyer_id}{/makeLink}" class="normal_bold">{$nearby.title|truncate:20}</a></span><br />
                                  {$nearby.location_city}&nbsp;{$nearby.location_zip} </td>
                                </tr>
                                <tr>
                                  <td align="left" valign="top">{$nearby.description|truncate:60}</td>
                                </tr>
                              </table>
							</div>
						    <div class="clear"></div>
						<div class="line_bg" style="padding-top:0px;"><!-- --></div>
				  </div>
				{/foreach}
				  	
					
					
					  
			  </div>
				
				<div class="rightbox_btm"><!-- --></div>
			</div>
			<!-- -->
			<div class="padding08"><!-- --></div>
			<div class="rightbox_wrap">
				<div class="rightbox_top"><!-- --></div>
				
				<div style="text-align:center;">
			<!--	<img src="{$GLOBAL.tpl_url}/images/ad_banner.jpg" alt="" width="160" height="600" />-->
			{$GADD2}
				</div>
				
				<div class="rightbox_btm"><!-- --></div>
			</div>
			
		</div>
		<!-- END:Right Wrap-->
		
		
		<br clear="all" />
	</div>
	
	
	
	
	
	
	
	
	
	
	
	
	
	
	
	
	
	
	
	<div onClick="event.cancelBubble = true;" class="popup" id="email_friend" style="width:450px;border:2px solid #000;background-color:#f1f1f1;">
<div id="slideDivFriend" class="expDiv" style="display:none;" >
	<form name="frmfriend" action="" method="post" >
	<table cellpadding="0" cellspacing="0" width="430px" border="0" style="margin-top:5px;margin-right:5px;margin-left:5px;margin-bottom:5px;"  >
		<tr>
			<td style="background-color:#f1f1f1;"></td>
		    <td style="background-color:#f1f1f1;"><div   style="float:right; cursor:pointer;" onClick="javascript:closePopup('email_friend','slideDivFriend');"><strong><img  src="{$GLOBAL.tpl_url}/images/close-button2.jpg"  border="0" alt="Close" /></strong></div></td>
		</tr>	
		<tr>
			<td colspan="2" style="padding-left:20px; " style="background-color:#f1f1f1;"><table width="100%"  border="0" align="left"  cellpadding="0" cellspacing="0" style="background-color:#f1f1f1;">
                      <tr>
                        <td width="34%" height="25" align="right"></td>
                        <td width="3%"></td>
                        <td width="63%" align="left"></td>
                      </tr>
					   <tr>
                        <td  colspan="3" align="center" class="head03" style="padding-bottom:6px" >Send To Friend</td>
                      </tr>
					   <tr>
                        <td  colspan="3" align="center" style="height:15px; "  ></td>
                       </tr>
                      <tr>
                        <td height="30" align="right"  class="name_wrap_field"><!-- {$MOD_VARIABLES.MOD_LABELS.LBL_YOUR_NAME} -->Your Name &nbsp;  </td>
                       
                        <td align="left" colspan="2" ><input name="name" id="name" type="text" style="width:205px; " class="text_field_form02" size="34" maxlength="150" value="{$smarty.request.first_name}" />
                            <span class="smalltext"></span></td>
                      </tr>
                      <tr>
                        <td height="30" align="right" class="name_wrap_field"><!-- {$MOD_VARIABLES.MOD_LABELS.LBL_YOUR_EMAIL} -->Your Email &nbsp; </td>
                       
                        <td align="left" colspan="2" ><input name="email" id="email" type="text" style="width:205px; " class="text_field_form02" size="34" maxlength="150" value="{$smarty.request.last_name}" /></td>
                      </tr>
                       <tr><td colspan="3">
                        <!-- {$MOD_VARIABLES.MOD_LABELS.LBL_EMAIL} --> 	Enter email addresses separated by commas 
						</td></tr>
                        <tr>
                        <td align="left" colspan="3"><table width="100%" cellpadding="0" cellspacing="0" border="0">
						<tr>
						<td width="33%"><textarea name="emailaddresses" id="emailaddresses" cols="45" rows="4" class="text_area" style="width:336px; ">{$smarty.request.address1}</textarea></td>
						<td width="67%"><div  class="row" style="display:inline;" id="emId"><div id="email_div" class="bluetext"><!-- {$MOD_VARIABLES.MOD_HINTS.HT_EMAIL} --></div></div></td>
						</tr>
						</table></td>
                      </tr>
                    
                     
                       <tr><td colspan="3">Message</td></tr>
                        <tr>
                        <td align="left" colspan="3"><table width="100%" cellpadding="0" cellspacing="0" border="0">
						<tr>
						<td width="33%"><textarea name="message" id="message" cols="45" rows="4" class="text_area" style="width:336px; ">{$smarty.request.address1}</textarea></td>
						<td width="67%"><div  class="row" style="display:inline;" id="emId"><div id="email_div" class="bluetext"><!-- {$MOD_VARIABLES.MOD_HINTS.HT_EMAIL} --></div></div></td>
						</tr>
						</table></td>
                      </tr>
                      
                     
                      
                     
                    
                       
					 
					   <tr>
                        <td align="right">&nbsp;</td>
                        <td >&nbsp;</td>
                        <td align="left" >&nbsp;</td>
                      </tr>
                   
                      <tr>
                        <td height="15" align="right">&nbsp;</td>
                        <td>&nbsp;</td>
                        <td align="left"><div id="but_profile_div"><table width="43%" border="0" cellspacing="0" cellpadding="0">
                            <tr>
                              <td width="53%" height="31"><a href="javascript:void(0);" class="redButton" onclick="javascript:sendtofriend(document.frmfriend);"><span>Submit</span></a>
</td>
                              <td width="47%"><a href="javascript:void(0);" class="redButton" onclick="javascript:closePopup('email_friend','slideDivFriend');"><span>Close</span></a>
</td>
                            </tr>
                        </table></div><div id="load_profile_div" style="display:none;float:left">Please wait...</div></td>
                      </tr>
                      <tr>
                        <td height="15" align="right">&nbsp;</td>
                        <td>&nbsp;</td>
                        <td align="left">&nbsp;</td>
                      </tr>
                    </table></td>
		</tr>
	</table>
	</form>
</div>		
</div>